//-------------------------------------------------------------------------
/*
Copyright (C) 2010 EDuke32 developers and contributors

This file is part of EDuke32.

EDuke32 is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License version 2
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
//-------------------------------------------------------------------------
#include "ns.h"	// Must come before everything else!

#include "compat.h"
#include "build.h"

#include "namesdyn.h"
#include "global.h"
#include "gamecontrol.h"

BEGIN_DUKE_NS

#define DVPTR(x) &x

int16_t DynamicTileMap[MAXTILES];

struct dynitem
{
    const char *str;
    int32_t *dynvalptr;
    const int16_t staticval;
    const int16_t staticval_rr;
};

static struct dynitem g_dynTileList[] =
{
    { "SECTOREFFECTOR", DVPTR(TILE_SECTOREFFECTOR), SECTOREFFECTOR__STATIC, SECTOREFFECTOR__STATICRR },
    { "ACTIVATOR", DVPTR(TILE_ACTIVATOR), ACTIVATOR__STATIC, ACTIVATOR__STATICRR },
    { "TOUCHPLATE", DVPTR(TILE_TOUCHPLATE), TOUCHPLATE__STATIC, TOUCHPLATE__STATICRR },
    { "ACTIVATORLOCKED", DVPTR(TILE_ACTIVATORLOCKED), ACTIVATORLOCKED__STATIC, ACTIVATORLOCKED__STATICRR },
    { "MUSICANDSFX", DVPTR(TILE_MUSICANDSFX), MUSICANDSFX__STATIC, MUSICANDSFX__STATICRR },
    { "LOCATORS", DVPTR(TILE_LOCATORS), LOCATORS__STATIC, LOCATORS__STATICRR },
    { "CYCLER", DVPTR(TILE_CYCLER), CYCLER__STATIC, CYCLER__STATICRR },
    { "MASTERSWITCH", DVPTR(TILE_MASTERSWITCH), MASTERSWITCH__STATIC, MASTERSWITCH__STATICRR },
    { "RESPAWN", DVPTR(TILE_RESPAWN), RESPAWN__STATIC, RESPAWN__STATICRR },
    { "GPSPEED", DVPTR(TILE_GPSPEED), GPSPEED__STATIC, GPSPEED__STATICRR },
    { "FOF", DVPTR(TILE_FOF), FOF__STATIC, FOF__STATICRR },
    { "ARROW", DVPTR(TILE_ARROW), ARROW__STATIC, ARROW__STATICRR },
    { "FIRSTGUNSPRITE", DVPTR(TILE_FIRSTGUNSPRITE), FIRSTGUNSPRITE__STATIC, FIRSTGUNSPRITE__STATICRR },
    { "CHAINGUNSPRITE", DVPTR(TILE_CHAINGUNSPRITE), CHAINGUNSPRITE__STATIC, CHAINGUNSPRITE__STATICRR },
    { "RPGSPRITE", DVPTR(TILE_RPGSPRITE), RPGSPRITE__STATIC, RPGSPRITE__STATICRR },
    { "FREEZESPRITE", DVPTR(TILE_FREEZESPRITE), FREEZESPRITE__STATIC, FREEZESPRITE__STATICRR },
    { "SHRINKERSPRITE", DVPTR(TILE_SHRINKERSPRITE), SHRINKERSPRITE__STATIC, SHRINKERSPRITE__STATICRR },
    { "HEAVYHBOMB", DVPTR(TILE_HEAVYHBOMB), HEAVYHBOMB__STATIC, HEAVYHBOMB__STATICRR },
    { "TRIPBOMBSPRITE", DVPTR(TILE_TRIPBOMBSPRITE), TRIPBOMBSPRITE__STATIC, TRIPBOMBSPRITE__STATICRR },
    { "SHOTGUNSPRITE", DVPTR(TILE_SHOTGUNSPRITE), SHOTGUNSPRITE__STATIC, SHOTGUNSPRITE__STATICRR },
    { "DEVISTATORSPRITE", DVPTR(TILE_DEVISTATORSPRITE), DEVISTATORSPRITE__STATIC, DEVISTATORSPRITE__STATICRR },
    { "HEALTHBOX", DVPTR(TILE_HEALTHBOX), HEALTHBOX__STATIC, HEALTHBOX__STATICRR },
    { "AMMOBOX", DVPTR(TILE_AMMOBOX), AMMOBOX__STATIC, AMMOBOX__STATICRR },
    { "GROWSPRITEICON", DVPTR(TILE_GROWSPRITEICON), GROWSPRITEICON__STATIC, GROWSPRITEICON__STATICRR },
    { "INVENTORYBOX", DVPTR(TILE_INVENTORYBOX), INVENTORYBOX__STATIC, INVENTORYBOX__STATICRR },
    { "FREEZEAMMO", DVPTR(TILE_FREEZEAMMO), FREEZEAMMO__STATIC, FREEZEAMMO__STATICRR },
    { "AMMO", DVPTR(TILE_AMMO), AMMO__STATIC, AMMO__STATICRR },
    { "BATTERYAMMO", DVPTR(TILE_BATTERYAMMO), BATTERYAMMO__STATIC, BATTERYAMMO__STATICRR },
    { "DEVISTATORAMMO", DVPTR(TILE_DEVISTATORAMMO), DEVISTATORAMMO__STATIC, DEVISTATORAMMO__STATICRR },
    { "RPGAMMO", DVPTR(TILE_RPGAMMO), RPGAMMO__STATIC, RPGAMMO__STATICRR },
    { "GROWAMMO", DVPTR(TILE_GROWAMMO), GROWAMMO__STATIC, GROWAMMO__STATICRR },
    { "CRYSTALAMMO", DVPTR(TILE_CRYSTALAMMO), CRYSTALAMMO__STATIC, CRYSTALAMMO__STATICRR },
    { "HBOMBAMMO", DVPTR(TILE_HBOMBAMMO), HBOMBAMMO__STATIC, HBOMBAMMO__STATICRR },
    { "AMMOLOTS", DVPTR(TILE_AMMOLOTS), AMMOLOTS__STATIC, AMMOLOTS__STATICRR },
    { "SHOTGUNAMMO", DVPTR(TILE_SHOTGUNAMMO), SHOTGUNAMMO__STATIC, SHOTGUNAMMO__STATICRR },
    { "COLA", DVPTR(TILE_COLA), COLA__STATIC, COLA__STATICRR },
    { "SIXPAK", DVPTR(TILE_SIXPAK), SIXPAK__STATIC, SIXPAK__STATICRR },
    { "FIRSTAID", DVPTR(TILE_FIRSTAID), FIRSTAID__STATIC, FIRSTAID__STATICRR },
    { "SHIELD", DVPTR(TILE_SHIELD), SHIELD__STATIC, SHIELD__STATICRR },
    { "STEROIDS", DVPTR(TILE_STEROIDS), STEROIDS__STATIC, STEROIDS__STATICRR },
    { "AIRTANK", DVPTR(TILE_AIRTANK), AIRTANK__STATIC, AIRTANK__STATICRR },
    { "JETPACK", DVPTR(TILE_JETPACK), JETPACK__STATIC, JETPACK__STATICRR },
    { "HEATSENSOR", DVPTR(TILE_HEATSENSOR), HEATSENSOR__STATIC, HEATSENSOR__STATICRR },
    { "ACCESSCARD", DVPTR(TILE_ACCESSCARD), ACCESSCARD__STATIC, ACCESSCARD__STATICRR },
    { "BOOTS", DVPTR(TILE_BOOTS), BOOTS__STATIC, BOOTS__STATICRR },
    { "MIRRORBROKE", DVPTR(TILE_MIRRORBROKE), MIRRORBROKE__STATIC, MIRRORBROKE__STATICRR },
    { "CLOUDYOCEAN", DVPTR(TILE_CLOUDYOCEAN), CLOUDYOCEAN__STATIC, 0 },
    { "CLOUDYSKIES", DVPTR(TILE_CLOUDYSKIES), CLOUDYSKIES__STATIC, CLOUDYSKIES__STATICRR },
    { "MOONSKY1", DVPTR(TILE_MOONSKY1), MOONSKY1__STATIC, MOONSKY1__STATICRR },
    { "MOONSKY2", DVPTR(TILE_MOONSKY2), MOONSKY2__STATIC, MOONSKY2__STATICRR },
    { "MOONSKY3", DVPTR(TILE_MOONSKY3), MOONSKY3__STATIC, MOONSKY3__STATICRR },
    { "MOONSKY4", DVPTR(TILE_MOONSKY4), MOONSKY4__STATIC, MOONSKY4__STATICRR },
    { "BIGORBIT1", DVPTR(TILE_BIGORBIT1), BIGORBIT1__STATIC, BIGORBIT1__STATICRR },
    { "BIGORBIT2", DVPTR(TILE_BIGORBIT2), BIGORBIT2__STATIC, BIGORBIT2__STATICRR },
    { "BIGORBIT3", DVPTR(TILE_BIGORBIT3), BIGORBIT3__STATIC, BIGORBIT3__STATICRR },
    { "BIGORBIT4", DVPTR(TILE_BIGORBIT4), BIGORBIT4__STATIC, BIGORBIT4__STATICRR },
    { "BIGORBIT5", DVPTR(TILE_BIGORBIT5), BIGORBIT5__STATIC, BIGORBIT5__STATICRR },
    { "LA", DVPTR(TILE_LA), LA__STATIC, LA__STATICRR },
    { "REDSKY1", DVPTR(TILE_REDSKY1), REDSKY1__STATIC, REDSKY1__STATICRR },
    { "REDSKY2", DVPTR(TILE_REDSKY2), REDSKY2__STATIC, REDSKY2__STATICRR },
    { "ATOMICHEALTH", DVPTR(TILE_ATOMICHEALTH), ATOMICHEALTH__STATIC, ATOMICHEALTH__STATICRR },
    { "TECHLIGHT2", DVPTR(TILE_TECHLIGHT2), TECHLIGHT2__STATIC, TECHLIGHT2__STATICRR },
    { "TECHLIGHTBUST2", DVPTR(TILE_TECHLIGHTBUST2), TECHLIGHTBUST2__STATIC, TECHLIGHTBUST2__STATICRR },
    { "TECHLIGHT4", DVPTR(TILE_TECHLIGHT4), TECHLIGHT4__STATIC, TECHLIGHT4__STATICRR },
    { "TECHLIGHTBUST4", DVPTR(TILE_TECHLIGHTBUST4), TECHLIGHTBUST4__STATIC, TECHLIGHTBUST4__STATICRR },
    { "WALLLIGHT4", DVPTR(TILE_WALLLIGHT4), WALLLIGHT4__STATIC, WALLLIGHT4__STATICRR },
    { "WALLLIGHTBUST4", DVPTR(TILE_WALLLIGHTBUST4), WALLLIGHTBUST4__STATIC, WALLLIGHTBUST4__STATICRR },
    { "ACCESSSWITCH", DVPTR(TILE_ACCESSSWITCH), ACCESSSWITCH__STATIC, ACCESSSWITCH__STATICRR },
    { "SLOTDOOR", DVPTR(TILE_SLOTDOOR), SLOTDOOR__STATIC, SLOTDOOR__STATICRR },
    { "LIGHTSWITCH", DVPTR(TILE_LIGHTSWITCH), LIGHTSWITCH__STATIC, LIGHTSWITCH__STATICRR },
    { "SPACEDOORSWITCH", DVPTR(TILE_SPACEDOORSWITCH), SPACEDOORSWITCH__STATIC, SPACEDOORSWITCH__STATICRR },
    { "SPACELIGHTSWITCH", DVPTR(TILE_SPACELIGHTSWITCH), SPACELIGHTSWITCH__STATIC, SPACELIGHTSWITCH__STATICRR },
    { "FRANKENSTINESWITCH", DVPTR(TILE_FRANKENSTINESWITCH), FRANKENSTINESWITCH__STATIC, FRANKENSTINESWITCH__STATICRR },
    { "NUKEBUTTON", DVPTR(TILE_NUKEBUTTON), NUKEBUTTON__STATIC, NUKEBUTTON__STATICRR },
    { "MULTISWITCH", DVPTR(TILE_MULTISWITCH), MULTISWITCH__STATIC, MULTISWITCH__STATICRR },
    { "DOORTILE5", DVPTR(TILE_DOORTILE5), DOORTILE5__STATIC, DOORTILE5__STATICRR },
    { "DOORTILE6", DVPTR(TILE_DOORTILE6), DOORTILE6__STATIC, DOORTILE6__STATICRR },
    { "DOORTILE1", DVPTR(TILE_DOORTILE1), DOORTILE1__STATIC, DOORTILE1__STATICRR },
    { "DOORTILE2", DVPTR(TILE_DOORTILE2), DOORTILE2__STATIC, DOORTILE2__STATICRR },
    { "DOORTILE3", DVPTR(TILE_DOORTILE3), DOORTILE3__STATIC, DOORTILE3__STATICRR },
    { "DOORTILE4", DVPTR(TILE_DOORTILE4), DOORTILE4__STATIC, DOORTILE4__STATICRR },
    { "DOORTILE7", DVPTR(TILE_DOORTILE7), DOORTILE7__STATIC, DOORTILE7__STATICRR },
    { "DOORTILE8", DVPTR(TILE_DOORTILE8), DOORTILE8__STATIC, DOORTILE8__STATICRR },
    { "DOORTILE9", DVPTR(TILE_DOORTILE9), DOORTILE9__STATIC, DOORTILE9__STATICRR },
    { "DOORTILE10", DVPTR(TILE_DOORTILE10), DOORTILE10__STATIC, DOORTILE10__STATICRR },
    { "DOORSHOCK", DVPTR(TILE_DOORSHOCK), DOORSHOCK__STATIC, DOORSHOCK__STATICRR },
    { "DIPSWITCH", DVPTR(TILE_DIPSWITCH), DIPSWITCH__STATIC, DIPSWITCH__STATICRR },
    { "DIPSWITCH2", DVPTR(TILE_DIPSWITCH2), DIPSWITCH2__STATIC, DIPSWITCH2__STATICRR },
    { "TECHSWITCH", DVPTR(TILE_TECHSWITCH), TECHSWITCH__STATIC, TECHSWITCH__STATICRR },
    { "DIPSWITCH3", DVPTR(TILE_DIPSWITCH3), DIPSWITCH3__STATIC, DIPSWITCH3__STATICRR },
    { "ACCESSSWITCH2", DVPTR(TILE_ACCESSSWITCH2), ACCESSSWITCH2__STATIC, ACCESSSWITCH2__STATICRR },
    { "REFLECTWATERTILE", DVPTR(TILE_REFLECTWATERTILE), REFLECTWATERTILE__STATIC, REFLECTWATERTILE__STATICRR },
    { "FLOORSLIME", DVPTR(TILE_FLOORSLIME), FLOORSLIME__STATIC, FLOORSLIME__STATICRR },
    { "BIGFORCE", DVPTR(TILE_BIGFORCE), BIGFORCE__STATIC, BIGFORCE__STATICRR },
    { "EPISODE", DVPTR(TILE_EPISODE), EPISODE__STATIC, EPISODE__STATICRR },
    { "MASKWALL9", DVPTR(TILE_MASKWALL9), MASKWALL9__STATIC, MASKWALL9__STATICRR },
    { "W_LIGHT", DVPTR(TILE_W_LIGHT), W_LIGHT__STATIC, W_LIGHT__STATICRR },
    { "SCREENBREAK1", DVPTR(TILE_SCREENBREAK1), SCREENBREAK1__STATIC, SCREENBREAK1__STATICRR },
    { "SCREENBREAK2", DVPTR(TILE_SCREENBREAK2), SCREENBREAK2__STATIC, SCREENBREAK2__STATICRR },
    { "SCREENBREAK3", DVPTR(TILE_SCREENBREAK3), SCREENBREAK3__STATIC, SCREENBREAK3__STATICRR },
    { "SCREENBREAK4", DVPTR(TILE_SCREENBREAK4), SCREENBREAK4__STATIC, SCREENBREAK4__STATICRR },
    { "SCREENBREAK5", DVPTR(TILE_SCREENBREAK5), SCREENBREAK5__STATIC, SCREENBREAK5__STATICRR },
    { "SCREENBREAK6", DVPTR(TILE_SCREENBREAK6), SCREENBREAK6__STATIC, SCREENBREAK6__STATICRR },
    { "SCREENBREAK7", DVPTR(TILE_SCREENBREAK7), SCREENBREAK7__STATIC, SCREENBREAK7__STATICRR },
    { "SCREENBREAK8", DVPTR(TILE_SCREENBREAK8), SCREENBREAK8__STATIC, SCREENBREAK8__STATICRR },
    { "SCREENBREAK9", DVPTR(TILE_SCREENBREAK9), SCREENBREAK9__STATIC, SCREENBREAK9__STATICRR },
    { "SCREENBREAK10", DVPTR(TILE_SCREENBREAK10), SCREENBREAK10__STATIC, SCREENBREAK10__STATICRR },
    { "SCREENBREAK11", DVPTR(TILE_SCREENBREAK11), SCREENBREAK11__STATIC, SCREENBREAK11__STATICRR },
    { "SCREENBREAK12", DVPTR(TILE_SCREENBREAK12), SCREENBREAK12__STATIC, SCREENBREAK12__STATICRR },
    { "SCREENBREAK13", DVPTR(TILE_SCREENBREAK13), SCREENBREAK13__STATIC, SCREENBREAK13__STATICRR },
    { "MASKWALL1", DVPTR(TILE_MASKWALL1), MASKWALL1__STATIC, MASKWALL1__STATICRR },
    { "W_TECHWALL1", DVPTR(TILE_W_TECHWALL1), W_TECHWALL1__STATIC, W_TECHWALL1__STATICRR },
    { "W_TECHWALL2", DVPTR(TILE_W_TECHWALL2), W_TECHWALL2__STATIC, W_TECHWALL2__STATICRR },
    { "W_TECHWALL15", DVPTR(TILE_W_TECHWALL15), W_TECHWALL15__STATIC, W_TECHWALL15__STATICRR },
    { "W_TECHWALL3", DVPTR(TILE_W_TECHWALL3), W_TECHWALL3__STATIC, W_TECHWALL3__STATICRR },
    { "W_TECHWALL4", DVPTR(TILE_W_TECHWALL4), W_TECHWALL4__STATIC, W_TECHWALL4__STATICRR },
    { "W_TECHWALL10", DVPTR(TILE_W_TECHWALL10), W_TECHWALL10__STATIC, W_TECHWALL10__STATICRR },
    { "W_TECHWALL16", DVPTR(TILE_W_TECHWALL16), W_TECHWALL16__STATIC, W_TECHWALL16__STATICRR },
    { "WATERTILE2", DVPTR(TILE_WATERTILE2), WATERTILE2__STATIC, WATERTILE2__STATICRR },
    { "BPANNEL1", DVPTR(TILE_BPANNEL1), BPANNEL1__STATIC, BPANNEL1__STATICRR },
    { "PANNEL1", DVPTR(TILE_PANNEL1), PANNEL1__STATIC, PANNEL1__STATICRR },
    { "PANNEL2", DVPTR(TILE_PANNEL2), PANNEL2__STATIC, PANNEL2__STATICRR },
    { "WATERTILE", DVPTR(TILE_WATERTILE), WATERTILE__STATIC, WATERTILE__STATICRR },
    { "STATIC", DVPTR(TILE_STATIC), STATIC__STATIC, STATIC__STATICRR },
    { "W_SCREENBREAK", DVPTR(TILE_W_SCREENBREAK), W_SCREENBREAK__STATIC, W_SCREENBREAK__STATICRR },
    { "W_HITTECHWALL3", DVPTR(TILE_W_HITTECHWALL3), W_HITTECHWALL3__STATIC, W_HITTECHWALL3__STATICRR },
    { "W_HITTECHWALL4", DVPTR(TILE_W_HITTECHWALL4), W_HITTECHWALL4__STATIC, W_HITTECHWALL4__STATICRR },
    { "W_HITTECHWALL2", DVPTR(TILE_W_HITTECHWALL2), W_HITTECHWALL2__STATIC, W_HITTECHWALL2__STATICRR },
    { "W_HITTECHWALL1", DVPTR(TILE_W_HITTECHWALL1), W_HITTECHWALL1__STATIC, W_HITTECHWALL1__STATICRR },
    { "MASKWALL10", DVPTR(TILE_MASKWALL10), MASKWALL10__STATIC, MASKWALL10__STATICRR },
    { "MASKWALL11", DVPTR(TILE_MASKWALL11), MASKWALL11__STATIC, MASKWALL11__STATICRR },
    { "DOORTILE22", DVPTR(TILE_DOORTILE22), DOORTILE22__STATIC, DOORTILE22__STATICRR },
    { "FANSPRITE", DVPTR(TILE_FANSPRITE), FANSPRITE__STATIC, FANSPRITE__STATICRR },
    { "FANSPRITEBROKE", DVPTR(TILE_FANSPRITEBROKE), FANSPRITEBROKE__STATIC, FANSPRITEBROKE__STATICRR },
    { "FANSHADOW", DVPTR(TILE_FANSHADOW), FANSHADOW__STATIC, FANSHADOW__STATICRR },
    { "FANSHADOWBROKE", DVPTR(TILE_FANSHADOWBROKE), FANSHADOWBROKE__STATIC, FANSHADOWBROKE__STATICRR },
    { "DOORTILE18", DVPTR(TILE_DOORTILE18), DOORTILE18__STATIC, DOORTILE18__STATICRR },
    { "DOORTILE19", DVPTR(TILE_DOORTILE19), DOORTILE19__STATIC, DOORTILE19__STATICRR },
    { "DOORTILE20", DVPTR(TILE_DOORTILE20), DOORTILE20__STATIC, DOORTILE20__STATICRR },
    { "SATELLITE", DVPTR(TILE_SATELLITE), SATELLITE__STATIC, SATELLITE__STATICRR },
    { "VIEWSCREEN2", DVPTR(TILE_VIEWSCREEN2), VIEWSCREEN2__STATIC, VIEWSCREEN2__STATICRR },
    { "VIEWSCREENBROKE", DVPTR(TILE_VIEWSCREENBROKE), VIEWSCREENBROKE__STATIC, VIEWSCREENBROKE__STATICRR },
    { "VIEWSCREEN", DVPTR(TILE_VIEWSCREEN), VIEWSCREEN__STATIC, VIEWSCREEN__STATICRR },
    { "GLASS", DVPTR(TILE_GLASS), GLASS__STATIC, GLASS__STATICRR },
    { "GLASS2", DVPTR(TILE_GLASS2), GLASS2__STATIC, GLASS2__STATICRR },
    { "STAINGLASS1", DVPTR(TILE_STAINGLASS1), STAINGLASS1__STATIC, STAINGLASS1__STATICRR },
    { "MASKWALL5", DVPTR(TILE_MASKWALL5), MASKWALL5__STATIC, MASKWALL5__STATICRR },
    { "SATELITE", DVPTR(TILE_SATELITE), SATELITE__STATIC, SATELITE__STATICRR },
    { "FUELPOD", DVPTR(TILE_FUELPOD), FUELPOD__STATIC, FUELPOD__STATICRR },
    { "SLIMEPIPE", DVPTR(TILE_SLIMEPIPE), SLIMEPIPE__STATIC, SLIMEPIPE__STATICRR },
    { "CRACK1", DVPTR(TILE_CRACK1), CRACK1__STATIC, CRACK1__STATICRR },
    { "CRACK2", DVPTR(TILE_CRACK2), CRACK2__STATIC, CRACK2__STATICRR },
    { "CRACK3", DVPTR(TILE_CRACK3), CRACK3__STATIC, CRACK3__STATICRR },
    { "CRACK4", DVPTR(TILE_CRACK4), CRACK4__STATIC, CRACK4__STATICRR },
    { "FOOTPRINTS", DVPTR(TILE_FOOTPRINTS), FOOTPRINTS__STATIC, FOOTPRINTS__STATICRR },
    { "DOMELITE", DVPTR(TILE_DOMELITE), DOMELITE__STATIC, DOMELITE__STATICRR },
    { "CAMERAPOLE", DVPTR(TILE_CAMERAPOLE), CAMERAPOLE__STATIC, CAMERAPOLE__STATICRR },
    { "CHAIR1", DVPTR(TILE_CHAIR1), CHAIR1__STATIC, CHAIR1__STATICRR },
    { "CHAIR2", DVPTR(TILE_CHAIR2), CHAIR2__STATIC, CHAIR2__STATICRR },
    { "BROKENCHAIR", DVPTR(TILE_BROKENCHAIR), BROKENCHAIR__STATIC, BROKENCHAIR__STATICRR },
    { "MIRROR", DVPTR(TILE_MIRROR), MIRROR__STATIC, MIRROR__STATICRR },
    { "WATERFOUNTAIN", DVPTR(TILE_WATERFOUNTAIN), WATERFOUNTAIN__STATIC, WATERFOUNTAIN__STATICRR },
    { "WATERFOUNTAINBROKE", DVPTR(TILE_WATERFOUNTAINBROKE), WATERFOUNTAINBROKE__STATIC, WATERFOUNTAINBROKE__STATICRR },
    { "FEMMAG1", DVPTR(TILE_FEMMAG1), FEMMAG1__STATIC, FEMMAG1__STATICRR },
    { "TOILET", DVPTR(TILE_TOILET), TOILET__STATIC, TOILET__STATICRR },
    { "STALL", DVPTR(TILE_STALL), STALL__STATIC, STALL__STATICRR },
    { "STALLBROKE", DVPTR(TILE_STALLBROKE), STALLBROKE__STATIC, STALLBROKE__STATICRR },
    { "FEMMAG2", DVPTR(TILE_FEMMAG2), FEMMAG2__STATIC, FEMMAG2__STATICRR },
    { "REACTOR2", DVPTR(TILE_REACTOR2), REACTOR2__STATIC, REACTOR2__STATICRR },
    { "REACTOR2BURNT", DVPTR(TILE_REACTOR2BURNT), REACTOR2BURNT__STATIC, REACTOR2BURNT__STATICRR },
    { "REACTOR2SPARK", DVPTR(TILE_REACTOR2SPARK), REACTOR2SPARK__STATIC, REACTOR2SPARK__STATICRR },
    { "GRATE1", DVPTR(TILE_GRATE1), GRATE1__STATIC, GRATE1__STATICRR },
    { "BGRATE1", DVPTR(TILE_BGRATE1), BGRATE1__STATIC, BGRATE1__STATICRR },
    { "SOLARPANNEL", DVPTR(TILE_SOLARPANNEL), SOLARPANNEL__STATIC, SOLARPANNEL__STATICRR },
    { "NAKED1", DVPTR(TILE_NAKED1), NAKED1__STATIC, NAKED1__STATICRR },
    { "ANTENNA", DVPTR(TILE_ANTENNA), ANTENNA__STATIC, ANTENNA__STATICRR },
    { "MASKWALL12", DVPTR(TILE_MASKWALL12), MASKWALL12__STATIC, MASKWALL12__STATICRR },
    { "TOILETBROKE", DVPTR(TILE_TOILETBROKE), TOILETBROKE__STATIC, TOILETBROKE__STATICRR },
    { "PIPE2", DVPTR(TILE_PIPE2), PIPE2__STATIC, PIPE2__STATICRR },
    { "PIPE1B", DVPTR(TILE_PIPE1B), PIPE1B__STATIC, PIPE1B__STATICRR },
    { "PIPE3", DVPTR(TILE_PIPE3), PIPE3__STATIC, PIPE3__STATICRR },
    { "PIPE1", DVPTR(TILE_PIPE1), PIPE1__STATIC, PIPE1__STATICRR },
    { "CAMERA1", DVPTR(TILE_CAMERA1), CAMERA1__STATIC, CAMERA1__STATICRR },
    { "BRICK", DVPTR(TILE_BRICK), BRICK__STATIC, BRICK__STATICRR },
    { "SPLINTERWOOD", DVPTR(TILE_SPLINTERWOOD), SPLINTERWOOD__STATIC, SPLINTERWOOD__STATICRR },
    { "PIPE2B", DVPTR(TILE_PIPE2B), PIPE2B__STATIC, PIPE2B__STATICRR },
    { "BOLT1", DVPTR(TILE_BOLT1), BOLT1__STATIC, BOLT1__STATICRR },
    { "W_NUMBERS", DVPTR(TILE_W_NUMBERS), W_NUMBERS__STATIC, W_NUMBERS__STATICRR },
    { "WATERDRIP", DVPTR(TILE_WATERDRIP), WATERDRIP__STATIC, WATERDRIP__STATICRR },
    { "WATERBUBBLE", DVPTR(TILE_WATERBUBBLE), WATERBUBBLE__STATIC, WATERBUBBLE__STATICRR },
    { "WATERBUBBLEMAKER", DVPTR(TILE_WATERBUBBLEMAKER), WATERBUBBLEMAKER__STATIC, WATERBUBBLEMAKER__STATICRR },
    { "W_FORCEFIELD", DVPTR(TILE_W_FORCEFIELD), W_FORCEFIELD__STATIC, W_FORCEFIELD__STATICRR },
    { "VACUUM", DVPTR(TILE_VACUUM), VACUUM__STATIC, VACUUM__STATICRR },
    { "FOOTPRINTS2", DVPTR(TILE_FOOTPRINTS2), FOOTPRINTS2__STATIC, FOOTPRINTS2__STATICRR },
    { "FOOTPRINTS3", DVPTR(TILE_FOOTPRINTS3), FOOTPRINTS3__STATIC, FOOTPRINTS3__STATICRR },
    { "FOOTPRINTS4", DVPTR(TILE_FOOTPRINTS4), FOOTPRINTS4__STATIC, FOOTPRINTS4__STATICRR },
    { "EGG", DVPTR(TILE_EGG), EGG__STATIC, EGG__STATICRR },
    { "SCALE", DVPTR(TILE_SCALE), SCALE__STATIC, SCALE__STATICRR },
    { "CHAIR3", DVPTR(TILE_CHAIR3), CHAIR3__STATIC, CHAIR3__STATICRR },
    { "CAMERALIGHT", DVPTR(TILE_CAMERALIGHT), CAMERALIGHT__STATIC, CAMERALIGHT__STATICRR },
    { "MOVIECAMERA", DVPTR(TILE_MOVIECAMERA), MOVIECAMERA__STATIC, MOVIECAMERA__STATICRR },
    { "IVUNIT", DVPTR(TILE_IVUNIT), IVUNIT__STATIC, IVUNIT__STATICRR },
    { "POT1", DVPTR(TILE_POT1), POT1__STATIC, POT1__STATICRR },
    { "POT2", DVPTR(TILE_POT2), POT2__STATIC, POT2__STATICRR },
    { "POT3", DVPTR(TILE_POT3), POT3__STATIC, POT3__STATICRR },
    { "PIPE3B", DVPTR(TILE_PIPE3B), PIPE3B__STATIC, PIPE3B__STATICRR },
    { "WALLLIGHT3", DVPTR(TILE_WALLLIGHT3), WALLLIGHT3__STATIC, WALLLIGHT3__STATICRR },
    { "WALLLIGHTBUST3", DVPTR(TILE_WALLLIGHTBUST3), WALLLIGHTBUST3__STATIC, WALLLIGHTBUST3__STATICRR },
    { "WALLLIGHT1", DVPTR(TILE_WALLLIGHT1), WALLLIGHT1__STATIC, WALLLIGHT1__STATICRR },
    { "WALLLIGHTBUST1", DVPTR(TILE_WALLLIGHTBUST1), WALLLIGHTBUST1__STATIC, WALLLIGHTBUST1__STATICRR },
    { "WALLLIGHT2", DVPTR(TILE_WALLLIGHT2), WALLLIGHT2__STATIC, WALLLIGHT2__STATICRR },
    { "WALLLIGHTBUST2", DVPTR(TILE_WALLLIGHTBUST2), WALLLIGHTBUST2__STATIC, WALLLIGHTBUST2__STATICRR },
    { "LIGHTSWITCH2", DVPTR(TILE_LIGHTSWITCH2), LIGHTSWITCH2__STATIC, LIGHTSWITCH2__STATICRR },
    { "WAITTOBESEATED", DVPTR(TILE_WAITTOBESEATED), WAITTOBESEATED__STATIC, WAITTOBESEATED__STATICRR },
    { "DOORTILE14", DVPTR(TILE_DOORTILE14), DOORTILE14__STATIC, DOORTILE14__STATICRR },
    { "STATUE", DVPTR(TILE_STATUE), STATUE__STATIC, STATUE__STATICRR },
    { "MIKE", DVPTR(TILE_MIKE), MIKE__STATIC, MIKE__STATICRR },
    { "VASE", DVPTR(TILE_VASE), VASE__STATIC, VASE__STATICRR },
    { "SUSHIPLATE1", DVPTR(TILE_SUSHIPLATE1), SUSHIPLATE1__STATIC, SUSHIPLATE1__STATICRR },
    { "SUSHIPLATE2", DVPTR(TILE_SUSHIPLATE2), SUSHIPLATE2__STATIC, SUSHIPLATE2__STATICRR },
    { "SUSHIPLATE3", DVPTR(TILE_SUSHIPLATE3), SUSHIPLATE3__STATIC, SUSHIPLATE3__STATICRR },
    { "SUSHIPLATE4", DVPTR(TILE_SUSHIPLATE4), SUSHIPLATE4__STATIC, SUSHIPLATE4__STATICRR },
    { "DOORTILE16", DVPTR(TILE_DOORTILE16), DOORTILE16__STATIC, DOORTILE16__STATICRR },
    { "SUSHIPLATE5", DVPTR(TILE_SUSHIPLATE5), SUSHIPLATE5__STATIC, SUSHIPLATE5__STATICRR },
    { "OJ", DVPTR(TILE_OJ), OJ__STATIC, OJ__STATICRR },
    { "MASKWALL13", DVPTR(TILE_MASKWALL13), MASKWALL13__STATIC, MASKWALL13__STATICRR },
    { "HURTRAIL", DVPTR(TILE_HURTRAIL), HURTRAIL__STATIC, HURTRAIL__STATICRR },
    { "POWERSWITCH1", DVPTR(TILE_POWERSWITCH1), POWERSWITCH1__STATIC, POWERSWITCH1__STATICRR },
    { "LOCKSWITCH1", DVPTR(TILE_LOCKSWITCH1), LOCKSWITCH1__STATIC, LOCKSWITCH1__STATICRR },
    { "POWERSWITCH2", DVPTR(TILE_POWERSWITCH2), POWERSWITCH2__STATIC, POWERSWITCH2__STATICRR },
    { "ATM", DVPTR(TILE_ATM), ATM__STATIC, ATM__STATICRR },
    { "STATUEFLASH", DVPTR(TILE_STATUEFLASH), STATUEFLASH__STATIC, STATUEFLASH__STATICRR },
    { "ATMBROKE", DVPTR(TILE_ATMBROKE), ATMBROKE__STATIC, ATMBROKE__STATICRR },
    { "BIGHOLE2", DVPTR(TILE_BIGHOLE2), BIGHOLE2__STATIC, BIGHOLE2__STATICRR },
    { "STRIPEBALL", DVPTR(TILE_STRIPEBALL), STRIPEBALL__STATIC, STRIPEBALL__STATICRR },
    { "QUEBALL", DVPTR(TILE_QUEBALL), QUEBALL__STATIC, QUEBALL__STATICRR },
    { "POCKET", DVPTR(TILE_POCKET), POCKET__STATIC, POCKET__STATICRR },
    { "WOODENHORSE", DVPTR(TILE_WOODENHORSE), WOODENHORSE__STATIC, WOODENHORSE__STATICRR },
    { "TREE1", DVPTR(TILE_TREE1), TREE1__STATIC, TREE1__STATICRR },
    { "TREE2", DVPTR(TILE_TREE2), TREE2__STATIC, TREE2__STATICRR },
    { "CACTUS", DVPTR(TILE_CACTUS), CACTUS__STATIC, CACTUS__STATICRR },
    { "MASKWALL2", DVPTR(TILE_MASKWALL2), MASKWALL2__STATIC, MASKWALL2__STATICRR },
    { "MASKWALL3", DVPTR(TILE_MASKWALL3), MASKWALL3__STATIC, MASKWALL3__STATICRR },
    { "MASKWALL4", DVPTR(TILE_MASKWALL4), MASKWALL4__STATIC, MASKWALL4__STATICRR },
    { "FIREEXT", DVPTR(TILE_FIREEXT), FIREEXT__STATIC, FIREEXT__STATICRR },
    { "TOILETWATER", DVPTR(TILE_TOILETWATER), TOILETWATER__STATIC, TOILETWATER__STATICRR },
    { "NEON1", DVPTR(TILE_NEON1), NEON1__STATIC, NEON1__STATICRR },
    { "NEON2", DVPTR(TILE_NEON2), NEON2__STATIC, NEON2__STATICRR },
    { "CACTUSBROKE", DVPTR(TILE_CACTUSBROKE), CACTUSBROKE__STATIC, CACTUSBROKE__STATICRR },
    { "BOUNCEMINE", DVPTR(TILE_BOUNCEMINE), BOUNCEMINE__STATIC, BOUNCEMINE__STATICRR },
    { "BROKEFIREHYDRENT", DVPTR(TILE_BROKEFIREHYDRENT), BROKEFIREHYDRENT__STATIC, BROKEFIREHYDRENT__STATICRR },
    { "BOX", DVPTR(TILE_BOX), BOX__STATIC, BOX__STATICRR },
    { "BULLETHOLE", DVPTR(TILE_BULLETHOLE), BULLETHOLE__STATIC, BULLETHOLE__STATICRR },
    { "BOTTLE1", DVPTR(TILE_BOTTLE1), BOTTLE1__STATIC, BOTTLE1__STATICRR },
    { "BOTTLE2", DVPTR(TILE_BOTTLE2), BOTTLE2__STATIC, BOTTLE2__STATICRR },
    { "BOTTLE3", DVPTR(TILE_BOTTLE3), BOTTLE3__STATIC, BOTTLE3__STATICRR },
    { "BOTTLE4", DVPTR(TILE_BOTTLE4), BOTTLE4__STATIC, BOTTLE4__STATICRR },
    { "FEMPIC5", DVPTR(TILE_FEMPIC5), FEMPIC5__STATIC, FEMPIC5__STATICRR },
    { "FEMPIC6", DVPTR(TILE_FEMPIC6), FEMPIC6__STATIC, FEMPIC6__STATICRR },
    { "FEMPIC7", DVPTR(TILE_FEMPIC7), FEMPIC7__STATIC, FEMPIC7__STATICRR },
    { "HYDROPLANT", DVPTR(TILE_HYDROPLANT), HYDROPLANT__STATIC, HYDROPLANT__STATICRR },
    { "OCEANSPRITE1", DVPTR(TILE_OCEANSPRITE1), OCEANSPRITE1__STATIC, OCEANSPRITE1__STATICRR },
    { "OCEANSPRITE2", DVPTR(TILE_OCEANSPRITE2), OCEANSPRITE2__STATIC, OCEANSPRITE2__STATICRR },
    { "OCEANSPRITE3", DVPTR(TILE_OCEANSPRITE3), OCEANSPRITE3__STATIC, OCEANSPRITE3__STATICRR },
    { "OCEANSPRITE4", DVPTR(TILE_OCEANSPRITE4), OCEANSPRITE4__STATIC, OCEANSPRITE4__STATICRR },
    { "OCEANSPRITE5", DVPTR(TILE_OCEANSPRITE5), OCEANSPRITE5__STATIC, OCEANSPRITE5__STATICRR },
    { "GENERICPOLE", DVPTR(TILE_GENERICPOLE), GENERICPOLE__STATIC, GENERICPOLE__STATICRR },
    { "CONE", DVPTR(TILE_CONE), CONE__STATIC, CONE__STATICRR },
    { "HANGLIGHT", DVPTR(TILE_HANGLIGHT), HANGLIGHT__STATIC, HANGLIGHT__STATICRR },
    { "HYDRENT", DVPTR(TILE_HYDRENT), HYDRENT__STATIC, HYDRENT__STATICRR },
    { "MASKWALL14", DVPTR(TILE_MASKWALL14), MASKWALL14__STATIC, MASKWALL14__STATICRR },
    { "TIRE", DVPTR(TILE_TIRE), TIRE__STATIC, TIRE__STATICRR },
    { "PIPE5", DVPTR(TILE_PIPE5), PIPE5__STATIC, PIPE5__STATICRR },
    { "PIPE6", DVPTR(TILE_PIPE6), PIPE6__STATIC, PIPE6__STATICRR },
    { "PIPE4", DVPTR(TILE_PIPE4), PIPE4__STATIC, PIPE4__STATICRR },
    { "PIPE4B", DVPTR(TILE_PIPE4B), PIPE4B__STATIC, PIPE4B__STATICRR },
    { "BROKEHYDROPLANT", DVPTR(TILE_BROKEHYDROPLANT), BROKEHYDROPLANT__STATIC, BROKEHYDROPLANT__STATICRR },
    { "PIPE5B", DVPTR(TILE_PIPE5B), PIPE5B__STATIC, PIPE5B__STATICRR },
    { "NEON3", DVPTR(TILE_NEON3), NEON3__STATIC, NEON3__STATICRR },
    { "NEON4", DVPTR(TILE_NEON4), NEON4__STATIC, NEON4__STATICRR },
    { "NEON5", DVPTR(TILE_NEON5), NEON5__STATIC, NEON5__STATICRR },
    { "BOTTLE5", DVPTR(TILE_BOTTLE5), BOTTLE5__STATIC, BOTTLE5__STATICRR },
    { "BOTTLE6", DVPTR(TILE_BOTTLE6), BOTTLE6__STATIC, BOTTLE6__STATICRR },
    { "BOTTLE8", DVPTR(TILE_BOTTLE8), BOTTLE8__STATIC, BOTTLE8__STATICRR },
    { "SPOTLITE", DVPTR(TILE_SPOTLITE), SPOTLITE__STATIC, SPOTLITE__STATICRR },
    { "HANGOOZ", DVPTR(TILE_HANGOOZ), HANGOOZ__STATIC, HANGOOZ__STATICRR },
    { "MASKWALL15", DVPTR(TILE_MASKWALL15), MASKWALL15__STATIC, MASKWALL15__STATICRR },
    { "BOTTLE7", DVPTR(TILE_BOTTLE7), BOTTLE7__STATIC, BOTTLE7__STATICRR },
    { "HORSEONSIDE", DVPTR(TILE_HORSEONSIDE), HORSEONSIDE__STATIC, HORSEONSIDE__STATICRR },
    { "GLASSPIECES", DVPTR(TILE_GLASSPIECES), GLASSPIECES__STATIC, GLASSPIECES__STATICRR },
    { "HORSELITE", DVPTR(TILE_HORSELITE), HORSELITE__STATIC, HORSELITE__STATICRR },
    { "DONUTS", DVPTR(TILE_DONUTS), DONUTS__STATIC, DONUTS__STATICRR },
    { "NEON6", DVPTR(TILE_NEON6), NEON6__STATIC, NEON6__STATICRR },
    { "MASKWALL6", DVPTR(TILE_MASKWALL6), MASKWALL6__STATIC, MASKWALL6__STATICRR },
    { "CLOCK", DVPTR(TILE_CLOCK), CLOCK__STATIC, CLOCK__STATICRR },
    { "RUBBERCAN", DVPTR(TILE_RUBBERCAN), RUBBERCAN__STATIC, RUBBERCAN__STATICRR },
    { "BROKENCLOCK", DVPTR(TILE_BROKENCLOCK), BROKENCLOCK__STATIC, BROKENCLOCK__STATICRR },
    { "PLUG", DVPTR(TILE_PLUG), PLUG__STATIC, PLUG__STATICRR },
    { "OOZFILTER", DVPTR(TILE_OOZFILTER), OOZFILTER__STATIC, OOZFILTER__STATICRR },
    { "FLOORPLASMA", DVPTR(TILE_FLOORPLASMA), FLOORPLASMA__STATIC, FLOORPLASMA__STATICRR },
    { "REACTOR", DVPTR(TILE_REACTOR), REACTOR__STATIC, REACTOR__STATICRR },
    { "REACTORSPARK", DVPTR(TILE_REACTORSPARK), REACTORSPARK__STATIC, REACTORSPARK__STATICRR },
    { "REACTORBURNT", DVPTR(TILE_REACTORBURNT), REACTORBURNT__STATIC, REACTORBURNT__STATICRR },
    { "DOORTILE15", DVPTR(TILE_DOORTILE15), DOORTILE15__STATIC, DOORTILE15__STATICRR },
    { "HANDSWITCH", DVPTR(TILE_HANDSWITCH), HANDSWITCH__STATIC, HANDSWITCH__STATICRR },
    { "CIRCLEPANNEL", DVPTR(TILE_CIRCLEPANNEL), CIRCLEPANNEL__STATIC, CIRCLEPANNEL__STATICRR },
    { "CIRCLEPANNELBROKE", DVPTR(TILE_CIRCLEPANNELBROKE), CIRCLEPANNELBROKE__STATIC, CIRCLEPANNELBROKE__STATICRR },
    { "PULLSWITCH", DVPTR(TILE_PULLSWITCH), PULLSWITCH__STATIC, PULLSWITCH__STATICRR },
    { "MASKWALL8", DVPTR(TILE_MASKWALL8), MASKWALL8__STATIC, MASKWALL8__STATICRR },
    { "BIGHOLE", DVPTR(TILE_BIGHOLE), BIGHOLE__STATIC, BIGHOLE__STATICRR },
    { "ALIENSWITCH", DVPTR(TILE_ALIENSWITCH), ALIENSWITCH__STATIC, ALIENSWITCH__STATICRR },
    { "DOORTILE21", DVPTR(TILE_DOORTILE21), DOORTILE21__STATIC, DOORTILE21__STATICRR },
    { "HANDPRINTSWITCH", DVPTR(TILE_HANDPRINTSWITCH), HANDPRINTSWITCH__STATIC, HANDPRINTSWITCH__STATICRR },
    { "BOTTLE10", DVPTR(TILE_BOTTLE10), BOTTLE10__STATIC, BOTTLE10__STATICRR },
    { "BOTTLE11", DVPTR(TILE_BOTTLE11), BOTTLE11__STATIC, BOTTLE11__STATICRR },
    { "BOTTLE12", DVPTR(TILE_BOTTLE12), BOTTLE12__STATIC, BOTTLE12__STATICRR },
    { "BOTTLE13", DVPTR(TILE_BOTTLE13), BOTTLE13__STATIC, BOTTLE13__STATICRR },
    { "BOTTLE14", DVPTR(TILE_BOTTLE14), BOTTLE14__STATIC, BOTTLE14__STATICRR },
    { "BOTTLE15", DVPTR(TILE_BOTTLE15), BOTTLE15__STATIC, BOTTLE15__STATICRR },
    { "BOTTLE16", DVPTR(TILE_BOTTLE16), BOTTLE16__STATIC, BOTTLE16__STATICRR },
    { "BOTTLE17", DVPTR(TILE_BOTTLE17), BOTTLE17__STATIC, BOTTLE17__STATICRR },
    { "BOTTLE18", DVPTR(TILE_BOTTLE18), BOTTLE18__STATIC, BOTTLE18__STATICRR },
    { "BOTTLE19", DVPTR(TILE_BOTTLE19), BOTTLE19__STATIC, BOTTLE19__STATICRR },
    { "DOORTILE17", DVPTR(TILE_DOORTILE17), DOORTILE17__STATIC, DOORTILE17__STATICRR },
    { "MASKWALL7", DVPTR(TILE_MASKWALL7), MASKWALL7__STATIC, MASKWALL7__STATICRR },
    { "JAILBARBREAK", DVPTR(TILE_JAILBARBREAK), JAILBARBREAK__STATIC, JAILBARBREAK__STATICRR },
    { "DOORTILE11", DVPTR(TILE_DOORTILE11), DOORTILE11__STATIC, DOORTILE11__STATICRR },
    { "DOORTILE12", DVPTR(TILE_DOORTILE12), DOORTILE12__STATIC, DOORTILE12__STATICRR },
    { "VENDMACHINE", DVPTR(TILE_VENDMACHINE), VENDMACHINE__STATIC, VENDMACHINE__STATICRR },
    { "VENDMACHINEBROKE", DVPTR(TILE_VENDMACHINEBROKE), VENDMACHINEBROKE__STATIC, VENDMACHINEBROKE__STATICRR },
    { "COLAMACHINE", DVPTR(TILE_COLAMACHINE), COLAMACHINE__STATIC, COLAMACHINE__STATICRR },
    { "COLAMACHINEBROKE", DVPTR(TILE_COLAMACHINEBROKE), COLAMACHINEBROKE__STATIC, COLAMACHINEBROKE__STATICRR },
    { "CRANEPOLE", DVPTR(TILE_CRANEPOLE), CRANEPOLE__STATIC, CRANEPOLE__STATICRR },
    { "CRANE", DVPTR(TILE_CRANE), CRANE__STATIC, CRANE__STATICRR },
    { "BARBROKE", DVPTR(TILE_BARBROKE), BARBROKE__STATIC, BARBROKE__STATICRR },
    { "BLOODPOOL", DVPTR(TILE_BLOODPOOL), BLOODPOOL__STATIC, BLOODPOOL__STATICRR },
    { "NUKEBARREL", DVPTR(TILE_NUKEBARREL), NUKEBARREL__STATIC, NUKEBARREL__STATICRR },
    { "NUKEBARRELDENTED", DVPTR(TILE_NUKEBARRELDENTED), NUKEBARRELDENTED__STATIC, NUKEBARRELDENTED__STATICRR },
    { "NUKEBARRELLEAKED", DVPTR(TILE_NUKEBARRELLEAKED), NUKEBARRELLEAKED__STATIC, NUKEBARRELLEAKED__STATICRR },
    { "CANWITHSOMETHING", DVPTR(TILE_CANWITHSOMETHING), CANWITHSOMETHING__STATIC, CANWITHSOMETHING__STATICRR },
    { "MONEY", DVPTR(TILE_MONEY), MONEY__STATIC, MONEY__STATICRR },
    { "BANNER", DVPTR(TILE_BANNER), BANNER__STATIC, BANNER__STATICRR },
    { "EXPLODINGBARREL", DVPTR(TILE_EXPLODINGBARREL), EXPLODINGBARREL__STATIC, EXPLODINGBARREL__STATICRR },
    { "EXPLODINGBARREL2", DVPTR(TILE_EXPLODINGBARREL2), EXPLODINGBARREL2__STATIC, EXPLODINGBARREL2__STATICRR },
    { "FIREBARREL", DVPTR(TILE_FIREBARREL), FIREBARREL__STATIC, FIREBARREL__STATICRR },
    { "SEENINE", DVPTR(TILE_SEENINE), SEENINE__STATIC, SEENINE__STATICRR },
    { "SEENINEDEAD", DVPTR(TILE_SEENINEDEAD), SEENINEDEAD__STATIC, SEENINEDEAD__STATICRR },
    { "STEAM", DVPTR(TILE_STEAM), STEAM__STATIC, STEAM__STATICRR },
    { "CEILINGSTEAM", DVPTR(TILE_CEILINGSTEAM), CEILINGSTEAM__STATIC, CEILINGSTEAM__STATICRR },
    { "PIPE6B", DVPTR(TILE_PIPE6B), PIPE6B__STATIC, PIPE6B__STATICRR },
    { "TRANSPORTERBEAM", DVPTR(TILE_TRANSPORTERBEAM), TRANSPORTERBEAM__STATIC, TRANSPORTERBEAM__STATICRR },
    { "RAT", DVPTR(TILE_RAT), RAT__STATIC, RAT__STATICRR },
    { "TRASH", DVPTR(TILE_TRASH), TRASH__STATIC, TRASH__STATICRR },
    { "FEMPIC1", DVPTR(TILE_FEMPIC1), FEMPIC1__STATIC, FEMPIC1__STATICRR },
    { "FEMPIC2", DVPTR(TILE_FEMPIC2), FEMPIC2__STATIC, FEMPIC2__STATICRR },
    { "BLANKSCREEN", DVPTR(TILE_BLANKSCREEN), BLANKSCREEN__STATIC, BLANKSCREEN__STATICRR },
    { "PODFEM1", DVPTR(TILE_PODFEM1), PODFEM1__STATIC, PODFEM1__STATICRR },
    { "FEMPIC3", DVPTR(TILE_FEMPIC3), FEMPIC3__STATIC, FEMPIC3__STATICRR },
    { "FEMPIC4", DVPTR(TILE_FEMPIC4), FEMPIC4__STATIC, FEMPIC4__STATICRR },
    { "FEM1", DVPTR(TILE_FEM1), FEM1__STATIC, FEM1__STATICRR },
    { "FEM2", DVPTR(TILE_FEM2), FEM2__STATIC, FEM2__STATICRR },
    { "FEM3", DVPTR(TILE_FEM3), FEM3__STATIC, FEM3__STATICRR },
    { "FEM5", DVPTR(TILE_FEM5), FEM5__STATIC, FEM5__STATICRR },
    { "BLOODYPOLE", DVPTR(TILE_BLOODYPOLE), BLOODYPOLE__STATIC, BLOODYPOLE__STATICRR },
    { "FEM4", DVPTR(TILE_FEM4), FEM4__STATIC, FEM4__STATICRR },
    { "FEM6", DVPTR(TILE_FEM6), FEM6__STATIC, FEM6__STATICRR },
    { "FEM6PAD", DVPTR(TILE_FEM6PAD), FEM6PAD__STATIC, FEM6PAD__STATICRR },
    { "FEM8", DVPTR(TILE_FEM8), FEM8__STATIC, FEM8__STATICRR },
    { "HELECOPT", DVPTR(TILE_HELECOPT), HELECOPT__STATIC, HELECOPT__STATICRR },
    { "FETUSJIB", DVPTR(TILE_FETUSJIB), FETUSJIB__STATIC, FETUSJIB__STATICRR },
    { "HOLODUKE", DVPTR(TILE_HOLODUKE), HOLODUKE__STATIC, HOLODUKE__STATICRR },
    { "SPACEMARINE", DVPTR(TILE_SPACEMARINE), SPACEMARINE__STATIC, SPACEMARINE__STATICRR },
    { "INDY", DVPTR(TILE_INDY), INDY__STATIC, INDY__STATICRR },
    { "FETUS", DVPTR(TILE_FETUS), FETUS__STATIC, FETUS__STATICRR },
    { "FETUSBROKE", DVPTR(TILE_FETUSBROKE), FETUSBROKE__STATIC, FETUSBROKE__STATICRR },
    { "MONK", DVPTR(TILE_MONK), MONK__STATIC, MONK__STATICRR },
    { "LUKE", DVPTR(TILE_LUKE), LUKE__STATIC, LUKE__STATICRR },
    { "COOLEXPLOSION1", DVPTR(TILE_COOLEXPLOSION1), COOLEXPLOSION1__STATIC, COOLEXPLOSION1__STATICRR },
    { "WATERSPLASH2", DVPTR(TILE_WATERSPLASH2), WATERSPLASH2__STATIC, WATERSPLASH2__STATICRR },
    { "FIREVASE", DVPTR(TILE_FIREVASE), FIREVASE__STATIC, FIREVASE__STATICRR },
    { "SCRATCH", DVPTR(TILE_SCRATCH), SCRATCH__STATIC, SCRATCH__STATICRR },
    { "FEM7", DVPTR(TILE_FEM7), FEM7__STATIC, FEM7__STATICRR },
    { "APLAYERTOP", DVPTR(TILE_APLAYERTOP), APLAYERTOP__STATIC, APLAYERTOP__STATICRR },
    { "APLAYER", DVPTR(TILE_APLAYER), APLAYER__STATIC, APLAYER__STATICRR },
    { "PLAYERONWATER", DVPTR(TILE_PLAYERONWATER), PLAYERONWATER__STATIC, PLAYERONWATER__STATICRR },
    { "DUKELYINGDEAD", DVPTR(TILE_DUKELYINGDEAD), DUKELYINGDEAD__STATIC, DUKELYINGDEAD__STATICRR },
    { "DUKETORSO", DVPTR(TILE_DUKETORSO), DUKETORSO__STATIC, DUKETORSO__STATICRR },
    { "DUKEGUN", DVPTR(TILE_DUKEGUN), DUKEGUN__STATIC, DUKEGUN__STATICRR },
    { "DUKELEG", DVPTR(TILE_DUKELEG), DUKELEG__STATIC, DUKELEG__STATICRR },
    { "SHARK", DVPTR(TILE_SHARK), SHARK__STATIC, SHARK__STATICRR },
    { "BLOOD", DVPTR(TILE_BLOOD), BLOOD__STATIC, BLOOD__STATICRR },
    { "FIRELASER", DVPTR(TILE_FIRELASER), FIRELASER__STATIC, FIRELASER__STATICRR },
    { "TRANSPORTERSTAR", DVPTR(TILE_TRANSPORTERSTAR), TRANSPORTERSTAR__STATIC, TRANSPORTERSTAR__STATICRR },
    { "SPIT", DVPTR(TILE_SPIT), SPIT__STATIC, SPIT__STATICRR },
    { "LOOGIE", DVPTR(TILE_LOOGIE), LOOGIE__STATIC, LOOGIE__STATICRR },
    { "FIST", DVPTR(TILE_FIST), FIST__STATIC, FIST__STATICRR },
    { "FREEZEBLAST", DVPTR(TILE_FREEZEBLAST), FREEZEBLAST__STATIC, FREEZEBLAST__STATICRR },
    { "DEVISTATORBLAST", DVPTR(TILE_DEVISTATORBLAST), DEVISTATORBLAST__STATIC, DEVISTATORBLAST__STATICRR },
    { "SHRINKSPARK", DVPTR(TILE_SHRINKSPARK), SHRINKSPARK__STATIC, SHRINKSPARK__STATICRR },
    { "TONGUE", DVPTR(TILE_TONGUE), TONGUE__STATIC, TONGUE__STATICRR },
    { "MORTER", DVPTR(TILE_MORTER), MORTER__STATIC, MORTER__STATICRR },
    { "SHRINKEREXPLOSION", DVPTR(TILE_SHRINKEREXPLOSION), SHRINKEREXPLOSION__STATIC, SHRINKEREXPLOSION__STATICRR },
    { "RADIUSEXPLOSION", DVPTR(TILE_RADIUSEXPLOSION), RADIUSEXPLOSION__STATIC, RADIUSEXPLOSION__STATICRR },
    { "FORCERIPPLE", DVPTR(TILE_FORCERIPPLE), FORCERIPPLE__STATIC, FORCERIPPLE__STATICRR },
    { "LIZTROOP", DVPTR(TILE_LIZTROOP), LIZTROOP__STATIC, 0 },
    { "LIZTROOPRUNNING", DVPTR(TILE_LIZTROOPRUNNING), LIZTROOPRUNNING__STATIC, 0 },
    { "LIZTROOPSTAYPUT", DVPTR(TILE_LIZTROOPSTAYPUT), LIZTROOPSTAYPUT__STATIC, 0 },
    { "LIZTOP", DVPTR(TILE_LIZTOP), LIZTOP__STATIC, 0 },
    { "LIZTROOPSHOOT", DVPTR(TILE_LIZTROOPSHOOT), LIZTROOPSHOOT__STATIC, 0 },
    { "LIZTROOPJETPACK", DVPTR(TILE_LIZTROOPJETPACK), LIZTROOPJETPACK__STATIC, 0 },
    { "LIZTROOPDSPRITE", DVPTR(TILE_LIZTROOPDSPRITE), LIZTROOPDSPRITE__STATIC, 0 },
    { "LIZTROOPONTOILET", DVPTR(TILE_LIZTROOPONTOILET), LIZTROOPONTOILET__STATIC, 0 },
    { "LIZTROOPJUSTSIT", DVPTR(TILE_LIZTROOPJUSTSIT), LIZTROOPJUSTSIT__STATIC, 0 },
    { "LIZTROOPDUCKING", DVPTR(TILE_LIZTROOPDUCKING), LIZTROOPDUCKING__STATIC, 0 },
    { "HEADJIB1", DVPTR(TILE_HEADJIB1), HEADJIB1__STATIC, 0 },
    { "ARMJIB1", DVPTR(TILE_ARMJIB1), ARMJIB1__STATIC, 0 },
    { "LEGJIB1", DVPTR(TILE_LEGJIB1), LEGJIB1__STATIC, 0 },
    { "CANNONBALL", DVPTR(TILE_CANNONBALL), CANNONBALL__STATIC, CANNONBALL__STATICRR },
    { "OCTABRAIN", DVPTR(TILE_OCTABRAIN), OCTABRAIN__STATIC, 0 },
    { "OCTABRAINSTAYPUT", DVPTR(TILE_OCTABRAINSTAYPUT), OCTABRAINSTAYPUT__STATIC, 0 },
    { "OCTATOP", DVPTR(TILE_OCTATOP), OCTATOP__STATIC, 0 },
    { "OCTADEADSPRITE", DVPTR(TILE_OCTADEADSPRITE), OCTADEADSPRITE__STATIC, 0 },
    { "INNERJAW", DVPTR(TILE_INNERJAW), INNERJAW__STATIC, INNERJAW__STATICRR },
    { "DRONE", DVPTR(TILE_DRONE), DRONE__STATIC, DRONE__STATICRR },
    { "EXPLOSION2", DVPTR(TILE_EXPLOSION2), EXPLOSION2__STATIC, EXPLOSION2__STATICRR },
    { "COMMANDER", DVPTR(TILE_COMMANDER), COMMANDER__STATIC, 0 },
    { "COMMANDERSTAYPUT", DVPTR(TILE_COMMANDERSTAYPUT), COMMANDERSTAYPUT__STATIC, 0 },
    { "RECON", DVPTR(TILE_RECON), RECON__STATIC, RECON__STATICRR },
    { "TANK", DVPTR(TILE_TANK), TANK__STATIC, 0 },
    { "PIGCOP", DVPTR(TILE_PIGCOP), PIGCOP__STATIC, 0 },
    { "PIGCOPSTAYPUT", DVPTR(TILE_PIGCOPSTAYPUT), PIGCOPSTAYPUT__STATIC, 0 },
    { "PIGCOPDIVE", DVPTR(TILE_PIGCOPDIVE), PIGCOPDIVE__STATIC, 0 },
    { "PIGCOPDEADSPRITE", DVPTR(TILE_PIGCOPDEADSPRITE), PIGCOPDEADSPRITE__STATIC, 0 },
    { "PIGTOP", DVPTR(TILE_PIGTOP), PIGTOP__STATIC, 0 },
    { "LIZMAN", DVPTR(TILE_LIZMAN), LIZMAN__STATIC, 0 },
    { "LIZMANSTAYPUT", DVPTR(TILE_LIZMANSTAYPUT), LIZMANSTAYPUT__STATIC, 0 },
    { "LIZMANSPITTING", DVPTR(TILE_LIZMANSPITTING), LIZMANSPITTING__STATIC, 0 },
    { "LIZMANFEEDING", DVPTR(TILE_LIZMANFEEDING), LIZMANFEEDING__STATIC, 0 },
    { "LIZMANJUMP", DVPTR(TILE_LIZMANJUMP), LIZMANJUMP__STATIC, 0 },
    { "LIZMANDEADSPRITE", DVPTR(TILE_LIZMANDEADSPRITE), LIZMANDEADSPRITE__STATIC, 0 },
    { "FECES", DVPTR(TILE_FECES), FECES__STATIC, FECES__STATICRR },
    { "LIZMANHEAD1", DVPTR(TILE_LIZMANHEAD1), LIZMANHEAD1__STATIC, 0 },
    { "LIZMANARM1", DVPTR(TILE_LIZMANARM1), LIZMANARM1__STATIC, 0 },
    { "LIZMANLEG1", DVPTR(TILE_LIZMANLEG1), LIZMANLEG1__STATIC, 0 },
    { "EXPLOSION2BOT", DVPTR(TILE_EXPLOSION2BOT), EXPLOSION2BOT__STATIC, EXPLOSION2BOT__STATICRR },
    { "USERWEAPON", DVPTR(TILE_USERWEAPON), USERWEAPON__STATIC, USERWEAPON__STATICRR },
    { "HEADERBAR", DVPTR(TILE_HEADERBAR), HEADERBAR__STATIC, HEADERBAR__STATICRR },
    { "JIBS1", DVPTR(TILE_JIBS1), JIBS1__STATIC, JIBS1__STATICRR },
    { "JIBS2", DVPTR(TILE_JIBS2), JIBS2__STATIC, JIBS2__STATICRR },
    { "JIBS3", DVPTR(TILE_JIBS3), JIBS3__STATIC, JIBS3__STATICRR },
    { "JIBS4", DVPTR(TILE_JIBS4), JIBS4__STATIC, JIBS4__STATICRR },
    { "JIBS5", DVPTR(TILE_JIBS5), JIBS5__STATIC, JIBS5__STATICRR },
    { "BURNING", DVPTR(TILE_BURNING), BURNING__STATIC, BURNING__STATICRR },
    { "FIRE", DVPTR(TILE_FIRE), FIRE__STATIC, FIRE__STATICRR },
    { "JIBS6", DVPTR(TILE_JIBS6), JIBS6__STATIC, JIBS6__STATICRR },
    { "BLOODSPLAT1", DVPTR(TILE_BLOODSPLAT1), BLOODSPLAT1__STATIC, BLOODSPLAT1__STATICRR },
    { "BLOODSPLAT3", DVPTR(TILE_BLOODSPLAT3), BLOODSPLAT3__STATIC, BLOODSPLAT3__STATICRR },
    { "BLOODSPLAT2", DVPTR(TILE_BLOODSPLAT2), BLOODSPLAT2__STATIC, BLOODSPLAT2__STATICRR },
    { "BLOODSPLAT4", DVPTR(TILE_BLOODSPLAT4), BLOODSPLAT4__STATIC, BLOODSPLAT4__STATICRR },
    { "OOZ", DVPTR(TILE_OOZ), OOZ__STATIC, OOZ__STATICRR },
    { "OOZ2", DVPTR(TILE_OOZ2), OOZ2__STATIC, OOZ2__STATICRR },
    { "WALLBLOOD1", DVPTR(TILE_WALLBLOOD1), WALLBLOOD1__STATIC, WALLBLOOD1__STATICRR },
    { "WALLBLOOD2", DVPTR(TILE_WALLBLOOD2), WALLBLOOD2__STATIC, WALLBLOOD2__STATICRR },
    { "WALLBLOOD3", DVPTR(TILE_WALLBLOOD3), WALLBLOOD3__STATIC, WALLBLOOD3__STATICRR },
    { "WALLBLOOD4", DVPTR(TILE_WALLBLOOD4), WALLBLOOD4__STATIC, WALLBLOOD4__STATICRR },
    { "WALLBLOOD5", DVPTR(TILE_WALLBLOOD5), WALLBLOOD5__STATIC, WALLBLOOD5__STATICRR },
    { "WALLBLOOD6", DVPTR(TILE_WALLBLOOD6), WALLBLOOD6__STATIC, WALLBLOOD6__STATICRR },
    { "WALLBLOOD7", DVPTR(TILE_WALLBLOOD7), WALLBLOOD7__STATIC, WALLBLOOD7__STATICRR },
    { "WALLBLOOD8", DVPTR(TILE_WALLBLOOD8), WALLBLOOD8__STATIC, WALLBLOOD8__STATICRR },
    { "BURNING2", DVPTR(TILE_BURNING2), BURNING2__STATIC, BURNING2__STATICRR },
    { "FIRE2", DVPTR(TILE_FIRE2), FIRE2__STATIC, FIRE2__STATICRR },
    { "CRACKKNUCKLES", DVPTR(TILE_CRACKKNUCKLES), CRACKKNUCKLES__STATIC, CRACKKNUCKLES__STATICRR },
    { "SMALLSMOKE", DVPTR(TILE_SMALLSMOKE), SMALLSMOKE__STATIC, SMALLSMOKE__STATICRR },
    { "SMALLSMOKEMAKER", DVPTR(TILE_SMALLSMOKEMAKER), SMALLSMOKEMAKER__STATIC, SMALLSMOKEMAKER__STATICRR },
    { "FLOORFLAME", DVPTR(TILE_FLOORFLAME), FLOORFLAME__STATIC, FLOORFLAME__STATICRR },
    { "ROTATEGUN", DVPTR(TILE_ROTATEGUN), ROTATEGUN__STATIC, ROTATEGUN__STATICRR },
    { "GREENSLIME", DVPTR(TILE_GREENSLIME), GREENSLIME__STATIC, GREENSLIME__STATICRR },
    { "WATERDRIPSPLASH", DVPTR(TILE_WATERDRIPSPLASH), WATERDRIPSPLASH__STATIC, WATERDRIPSPLASH__STATICRR },
    { "SCRAP6", DVPTR(TILE_SCRAP6), SCRAP6__STATIC, SCRAP6__STATICRR },
    { "SCRAP1", DVPTR(TILE_SCRAP1), SCRAP1__STATIC, SCRAP1__STATICRR },
    { "SCRAP2", DVPTR(TILE_SCRAP2), SCRAP2__STATIC, SCRAP2__STATICRR },
    { "SCRAP3", DVPTR(TILE_SCRAP3), SCRAP3__STATIC, SCRAP3__STATICRR },
    { "SCRAP4", DVPTR(TILE_SCRAP4), SCRAP4__STATIC, SCRAP4__STATICRR },
    { "SCRAP5", DVPTR(TILE_SCRAP5), SCRAP5__STATIC, SCRAP5__STATICRR },
    { "ORGANTIC", DVPTR(TILE_ORGANTIC), ORGANTIC__STATIC, ORGANTIC__STATICRR },
    { "BETAVERSION", DVPTR(TILE_BETAVERSION), BETAVERSION__STATIC, BETAVERSION__STATICRR },
    { "PLAYERISHERE", DVPTR(TILE_PLAYERISHERE), PLAYERISHERE__STATIC, PLAYERISHERE__STATICRR },
    { "PLAYERWASHERE", DVPTR(TILE_PLAYERWASHERE), PLAYERWASHERE__STATIC, PLAYERWASHERE__STATICRR },
    { "SELECTDIR", DVPTR(TILE_SELECTDIR), SELECTDIR__STATIC, SELECTDIR__STATICRR },
    { "F1HELP", DVPTR(TILE_F1HELP), F1HELP__STATIC, F1HELP__STATICRR },
    { "NOTCHON", DVPTR(TILE_NOTCHON), NOTCHON__STATIC, NOTCHON__STATICRR },
    { "NOTCHOFF", DVPTR(TILE_NOTCHOFF), NOTCHOFF__STATIC, NOTCHOFF__STATICRR },
    { "GROWSPARK", DVPTR(TILE_GROWSPARK), GROWSPARK__STATIC, GROWSPARK__STATICRR },
    { "DUKEICON", DVPTR(TILE_DUKEICON), DUKEICON__STATIC, DUKEICON__STATICRR },
    { "BADGUYICON", DVPTR(TILE_BADGUYICON), BADGUYICON__STATIC, BADGUYICON__STATICRR },
    { "FOODICON", DVPTR(TILE_FOODICON), FOODICON__STATIC, FOODICON__STATICRR },
    { "GETICON", DVPTR(TILE_GETICON), GETICON__STATIC, GETICON__STATICRR },
    { "MENUSCREEN", DVPTR(TILE_MENUSCREEN), MENUSCREEN__STATIC, MENUSCREEN__STATICRR },
    { "MENUBAR", DVPTR(TILE_MENUBAR), MENUBAR__STATIC, MENUBAR__STATICRR },
    { "KILLSICON", DVPTR(TILE_KILLSICON), KILLSICON__STATIC, KILLSICON__STATICRR },
    { "FIRSTAID_ICON", DVPTR(TILE_FIRSTAID_ICON), FIRSTAID_ICON__STATIC, FIRSTAID_ICON__STATICRR },
    { "HEAT_ICON", DVPTR(TILE_HEAT_ICON), HEAT_ICON__STATIC, HEAT_ICON__STATICRR },
    { "BOTTOMSTATUSBAR", DVPTR(TILE_BOTTOMSTATUSBAR), BOTTOMSTATUSBAR__STATIC, BOTTOMSTATUSBAR__STATICRR },
    { "BOOT_ICON", DVPTR(TILE_BOOT_ICON), BOOT_ICON__STATIC, BOOT_ICON__STATICRR },
    { "FRAGBAR", DVPTR(TILE_FRAGBAR), FRAGBAR__STATIC, FRAGBAR__STATICRR },
    { "JETPACK_ICON", DVPTR(TILE_JETPACK_ICON), JETPACK_ICON__STATIC, JETPACK_ICON__STATICRR },
    { "AIRTANK_ICON", DVPTR(TILE_AIRTANK_ICON), AIRTANK_ICON__STATIC, AIRTANK_ICON__STATICRR },
    { "STEROIDS_ICON", DVPTR(TILE_STEROIDS_ICON), STEROIDS_ICON__STATIC, STEROIDS_ICON__STATICRR },
    { "HOLODUKE_ICON", DVPTR(TILE_HOLODUKE_ICON), HOLODUKE_ICON__STATIC, HOLODUKE_ICON__STATICRR },
    { "ACCESS_ICON", DVPTR(TILE_ACCESS_ICON), ACCESS_ICON__STATIC, ACCESS_ICON__STATICRR },
    { "DIGITALNUM", DVPTR(TILE_DIGITALNUM), DIGITALNUM__STATIC, DIGITALNUM__STATICRR },
    { "DUKECAR", DVPTR(TILE_DUKECAR), DUKECAR__STATIC, DUKECAR__STATICRR },
    { "CAMCORNER", DVPTR(TILE_CAMCORNER), CAMCORNER__STATIC, CAMCORNER__STATICRR },
    { "CAMLIGHT", DVPTR(TILE_CAMLIGHT), CAMLIGHT__STATIC, CAMLIGHT__STATICRR },
    { "LOGO", DVPTR(TILE_LOGO), LOGO__STATIC, LOGO__STATICRR },
    { "TITLE", DVPTR(TILE_TITLE), TITLE__STATIC, TITLE__STATICRR },
    { "NUKEWARNINGICON", DVPTR(TILE_NUKEWARNINGICON), NUKEWARNINGICON__STATIC, NUKEWARNINGICON__STATICRR },
    { "MOUSECURSOR", DVPTR(TILE_MOUSECURSOR), MOUSECURSOR__STATIC, MOUSECURSOR__STATICRR },
    { "SLIDEBAR", DVPTR(TILE_SLIDEBAR), SLIDEBAR__STATIC, SLIDEBAR__STATICRR },
    { "DREALMS", DVPTR(TILE_DREALMS), DREALMS__STATIC, DREALMS__STATICRR },
    { "BETASCREEN", DVPTR(TILE_BETASCREEN), BETASCREEN__STATIC, BETASCREEN__STATICRR },
    { "WINDOWBORDER1", DVPTR(TILE_WINDOWBORDER1), WINDOWBORDER1__STATIC, WINDOWBORDER1__STATICRR },
    { "TEXTBOX", DVPTR(TILE_TEXTBOX), TEXTBOX__STATIC, TEXTBOX__STATICRR },
    { "WINDOWBORDER2", DVPTR(TILE_WINDOWBORDER2), WINDOWBORDER2__STATIC, WINDOWBORDER2__STATICRR },
    { "DUKENUKEM", DVPTR(TILE_DUKENUKEM), DUKENUKEM__STATIC, DUKENUKEM__STATICRR },
    { "THREEDEE", DVPTR(TILE_THREEDEE), THREEDEE__STATIC, THREEDEE__STATICRR },
    { "INGAMEDUKETHREEDEE", DVPTR(TILE_INGAMEDUKETHREEDEE), INGAMEDUKETHREEDEE__STATIC, INGAMEDUKETHREEDEE__STATICRR },
    { "TENSCREEN", DVPTR(TILE_TENSCREEN), TENSCREEN__STATIC, TENSCREEN__STATICRR },
    { "PLUTOPAKSPRITE", DVPTR(TILE_PLUTOPAKSPRITE), PLUTOPAKSPRITE__STATIC, PLUTOPAKSPRITE__STATICRR },
    { "DEVISTATOR", DVPTR(TILE_DEVISTATOR), DEVISTATOR__STATIC, DEVISTATOR__STATICRR },
    { "KNEE", DVPTR(TILE_KNEE), KNEE__STATIC, KNEE__STATICRR },
    { "CROSSHAIR", DVPTR(TILE_CROSSHAIR), CROSSHAIR__STATIC, CROSSHAIR__STATICRR },
    { "FIRSTGUN", DVPTR(TILE_FIRSTGUN), FIRSTGUN__STATIC, FIRSTGUN__STATICRR },
    { "FIRSTGUNRELOAD", DVPTR(TILE_FIRSTGUNRELOAD), FIRSTGUNRELOAD__STATIC, FIRSTGUNRELOAD__STATICRR },
    { "FALLINGCLIP", DVPTR(TILE_FALLINGCLIP), FALLINGCLIP__STATIC, FALLINGCLIP__STATICRR },
    { "CLIPINHAND", DVPTR(TILE_CLIPINHAND), CLIPINHAND__STATIC, CLIPINHAND__STATICRR },
    { "HAND", DVPTR(TILE_HAND), HAND__STATIC, HAND__STATICRR },
    { "SHELL", DVPTR(TILE_SHELL), SHELL__STATIC, SHELL__STATICRR },
    { "SHOTGUNSHELL", DVPTR(TILE_SHOTGUNSHELL), SHOTGUNSHELL__STATIC, SHOTGUNSHELL__STATICRR },
    { "CHAINGUN", DVPTR(TILE_CHAINGUN), CHAINGUN__STATIC, CHAINGUN__STATICRR },
    { "RPGGUN", DVPTR(TILE_RPGGUN), RPGGUN__STATIC, RPGGUN__STATICRR },
    { "RPGMUZZLEFLASH", DVPTR(TILE_RPGMUZZLEFLASH), RPGMUZZLEFLASH__STATIC, RPGMUZZLEFLASH__STATICRR },
    { "FREEZE", DVPTR(TILE_FREEZE), FREEZE__STATIC, FREEZE__STATICRR },
    { "CATLITE", DVPTR(TILE_CATLITE), CATLITE__STATIC, CATLITE__STATICRR },
    { "SHRINKER", DVPTR(TILE_SHRINKER), SHRINKER__STATIC, SHRINKER__STATICRR },
    { "HANDHOLDINGLASER", DVPTR(TILE_HANDHOLDINGLASER), HANDHOLDINGLASER__STATIC, HANDHOLDINGLASER__STATICRR },
    { "TRIPBOMB", DVPTR(TILE_TRIPBOMB), TRIPBOMB__STATIC, TRIPBOMB__STATICRR },
    { "LASERLINE", DVPTR(TILE_LASERLINE), LASERLINE__STATIC, LASERLINE__STATICRR },
    { "HANDHOLDINGACCESS", DVPTR(TILE_HANDHOLDINGACCESS), HANDHOLDINGACCESS__STATIC, HANDHOLDINGACCESS__STATICRR },
    { "HANDREMOTE", DVPTR(TILE_HANDREMOTE), HANDREMOTE__STATIC, HANDREMOTE__STATICRR },
    { "HANDTHROW", DVPTR(TILE_HANDTHROW), HANDTHROW__STATIC, HANDTHROW__STATICRR },
    { "TIP", DVPTR(TILE_TIP), TIP__STATIC, TIP__STATICRR },
    { "GLAIR", DVPTR(TILE_GLAIR), GLAIR__STATIC, GLAIR__STATICRR },
    { "SCUBAMASK", DVPTR(TILE_SCUBAMASK), SCUBAMASK__STATIC, SCUBAMASK__STATICRR },
    { "SPACEMASK", DVPTR(TILE_SPACEMASK), SPACEMASK__STATIC, SPACEMASK__STATICRR },
    { "FORCESPHERE", DVPTR(TILE_FORCESPHERE), FORCESPHERE__STATIC, FORCESPHERE__STATICRR },
    { "SHOTSPARK1", DVPTR(TILE_SHOTSPARK1), SHOTSPARK1__STATIC, SHOTSPARK1__STATICRR },
    { "RPG", DVPTR(TILE_RPG), RPG__STATIC, RPG__STATICRR },
    { "LASERSITE", DVPTR(TILE_LASERSITE), LASERSITE__STATIC, 0 },
    { "SHOTGUN", DVPTR(TILE_SHOTGUN), SHOTGUN__STATIC, SHOTGUN__STATICRR },
    { "BOSS1", DVPTR(TILE_BOSS1), BOSS1__STATIC, BOSS1__STATICRR },
    { "BOSS1STAYPUT", DVPTR(TILE_BOSS1STAYPUT), BOSS1STAYPUT__STATIC, 0 },
    { "BOSS1SHOOT", DVPTR(TILE_BOSS1SHOOT), BOSS1SHOOT__STATIC, 0 },
    { "BOSS1LOB", DVPTR(TILE_BOSS1LOB), BOSS1LOB__STATIC, 0 },
    { "BOSSTOP", DVPTR(TILE_BOSSTOP), BOSSTOP__STATIC, 0 },
    { "BOSS2", DVPTR(TILE_BOSS2), BOSS2__STATIC, BOSS2__STATICRR },
    { "BOSS3", DVPTR(TILE_BOSS3), BOSS3__STATIC, BOSS3__STATICRR },
    { "SPINNINGNUKEICON", DVPTR(TILE_SPINNINGNUKEICON), SPINNINGNUKEICON__STATIC, SPINNINGNUKEICON__STATICRR },
    { "BIGFNTCURSOR", DVPTR(TILE_BIGFNTCURSOR), BIGFNTCURSOR__STATIC, BIGFNTCURSOR__STATICRR },
    { "SMALLFNTCURSOR", DVPTR(TILE_SMALLFNTCURSOR), SMALLFNTCURSOR__STATIC, SMALLFNTCURSOR__STATICRR },
    { "STARTALPHANUM", DVPTR(TILE_STARTALPHANUM), STARTALPHANUM__STATIC, STARTALPHANUM__STATICRR },
    { "ENDALPHANUM", DVPTR(TILE_ENDALPHANUM), ENDALPHANUM__STATIC, ENDALPHANUM__STATICRR },
    { "BIGALPHANUM", DVPTR(TILE_BIGALPHANUM), BIGALPHANUM__STATIC, BIGALPHANUM__STATICRR },
    { "BIGPERIOD", DVPTR(TILE_BIGPERIOD), BIGPERIOD__STATIC, BIGPERIOD__STATICRR },
    { "BIGCOMMA", DVPTR(TILE_BIGCOMMA), BIGCOMMA__STATIC, BIGCOMMA__STATICRR },
    { "BIGX", DVPTR(TILE_BIGX_), BIGX__STATIC, BIGX__STATICRR },
    { "BIGQ", DVPTR(TILE_BIGQ), BIGQ__STATIC, BIGQ__STATICRR },
    { "BIGSEMI", DVPTR(TILE_BIGSEMI), BIGSEMI__STATIC, BIGSEMI__STATICRR },
    { "BIGCOLIN", DVPTR(TILE_BIGCOLIN), BIGCOLIN__STATIC, BIGCOLIN__STATICRR },
    { "THREEBYFIVE", DVPTR(TILE_THREEBYFIVE), THREEBYFIVE__STATIC, THREEBYFIVE__STATICRR },
    { "BIGAPPOS", DVPTR(TILE_BIGAPPOS), BIGAPPOS__STATIC, BIGAPPOS__STATICRR },
    { "BLANK", DVPTR(TILE_BLANK), BLANK__STATIC, BLANK__STATICRR },
    { "MINIFONT", DVPTR(TILE_MINIFONT), MINIFONT__STATIC, MINIFONT__STATICRR },
    { "BUTTON1", DVPTR(TILE_BUTTON1), BUTTON1__STATIC, BUTTON1__STATICRR },
    { "GLASS3", DVPTR(TILE_GLASS3), GLASS3__STATIC, GLASS3__STATICRR },
    { "RESPAWNMARKERRED", DVPTR(TILE_RESPAWNMARKERRED), RESPAWNMARKERRED__STATIC, RESPAWNMARKERRED__STATICRR },
    { "RESPAWNMARKERYELLOW", DVPTR(TILE_RESPAWNMARKERYELLOW), RESPAWNMARKERYELLOW__STATIC, RESPAWNMARKERYELLOW__STATICRR },
    { "RESPAWNMARKERGREEN", DVPTR(TILE_RESPAWNMARKERGREEN), RESPAWNMARKERGREEN__STATIC, RESPAWNMARKERGREEN__STATICRR },
    { "BONUSSCREEN", DVPTR(TILE_BONUSSCREEN), BONUSSCREEN__STATIC, BONUSSCREEN__STATICRR },
    { "VIEWBORDER", DVPTR(TILE_VIEWBORDER), VIEWBORDER__STATIC, VIEWBORDER__STATICRR },
    { "VICTORY1", DVPTR(TILE_VICTORY1), VICTORY1__STATIC, VICTORY1__STATICRR },
    { "ORDERING", DVPTR(TILE_ORDERING), ORDERING__STATIC, ORDERING__STATICRR },
    { "TEXTSTORY", DVPTR(TILE_TEXTSTORY), TEXTSTORY__STATIC, TEXTSTORY__STATICRR },
    { "LOADSCREEN", DVPTR(TILE_LOADSCREEN), LOADSCREEN__STATIC, LOADSCREEN__STATICRR },
    { "BORNTOBEWILDSCREEN", DVPTR(TILE_BORNTOBEWILDSCREEN), BORNTOBEWILDSCREEN__STATIC, BORNTOBEWILDSCREEN__STATICRR },
    { "BLIMP", DVPTR(TILE_BLIMP), BLIMP__STATIC, BLIMP__STATICRR },
    { "FEM9", DVPTR(TILE_FEM9), FEM9__STATIC, FEM9__STATICRR },
    { "FOOTPRINT", DVPTR(TILE_FOOTPRINT), FOOTPRINT__STATIC, FOOTPRINT__STATICRR },
    { "POOP", DVPTR(TILE_POOP), POOP__STATIC, POOP__STATICRR },
    { "FRAMEEFFECT1", DVPTR(TILE_FRAMEEFFECT1), FRAMEEFFECT1__STATIC, FRAMEEFFECT1__STATICRR },
    { "PANNEL3", DVPTR(TILE_PANNEL3), PANNEL3__STATIC, PANNEL3__STATICRR },
    { "SCREENBREAK14", DVPTR(TILE_SCREENBREAK14), SCREENBREAK14__STATIC, SCREENBREAK14__STATICRR },
    { "SCREENBREAK15", DVPTR(TILE_SCREENBREAK15), SCREENBREAK15__STATIC, SCREENBREAK15__STATICRR },
    { "SCREENBREAK19", DVPTR(TILE_SCREENBREAK19), SCREENBREAK19__STATIC, SCREENBREAK19__STATICRR },
    { "SCREENBREAK16", DVPTR(TILE_SCREENBREAK16), SCREENBREAK16__STATIC, SCREENBREAK16__STATICRR },
    { "SCREENBREAK17", DVPTR(TILE_SCREENBREAK17), SCREENBREAK17__STATIC, SCREENBREAK17__STATICRR },
    { "SCREENBREAK18", DVPTR(TILE_SCREENBREAK18), SCREENBREAK18__STATIC, SCREENBREAK18__STATICRR },
    { "W_TECHWALL11", DVPTR(TILE_W_TECHWALL11), W_TECHWALL11__STATIC, W_TECHWALL11__STATICRR },
    { "W_TECHWALL12", DVPTR(TILE_W_TECHWALL12), W_TECHWALL12__STATIC, W_TECHWALL12__STATICRR },
    { "W_TECHWALL13", DVPTR(TILE_W_TECHWALL13), W_TECHWALL13__STATIC, W_TECHWALL13__STATICRR },
    { "W_TECHWALL14", DVPTR(TILE_W_TECHWALL14), W_TECHWALL14__STATIC, W_TECHWALL14__STATICRR },
    { "W_TECHWALL5", DVPTR(TILE_W_TECHWALL5), W_TECHWALL5__STATIC, W_TECHWALL5__STATICRR },
    { "W_TECHWALL6", DVPTR(TILE_W_TECHWALL6), W_TECHWALL6__STATIC, W_TECHWALL6__STATICRR },
    { "W_TECHWALL7", DVPTR(TILE_W_TECHWALL7), W_TECHWALL7__STATIC, W_TECHWALL7__STATICRR },
    { "W_TECHWALL8", DVPTR(TILE_W_TECHWALL8), W_TECHWALL8__STATIC, W_TECHWALL8__STATICRR },
    { "W_TECHWALL9", DVPTR(TILE_W_TECHWALL9), W_TECHWALL9__STATIC, W_TECHWALL9__STATICRR },
    { "BPANNEL3", DVPTR(TILE_BPANNEL3), BPANNEL3__STATIC, BPANNEL3__STATICRR },
    { "W_HITTECHWALL16", DVPTR(TILE_W_HITTECHWALL16), W_HITTECHWALL16__STATIC, W_HITTECHWALL16__STATICRR },
    { "W_HITTECHWALL10", DVPTR(TILE_W_HITTECHWALL10), W_HITTECHWALL10__STATIC, W_HITTECHWALL10__STATICRR },
    { "W_HITTECHWALL15", DVPTR(TILE_W_HITTECHWALL15), W_HITTECHWALL15__STATIC, W_HITTECHWALL15__STATICRR },
    { "W_MILKSHELF", DVPTR(TILE_W_MILKSHELF), W_MILKSHELF__STATIC, W_MILKSHELF__STATICRR },
    { "W_MILKSHELFBROKE", DVPTR(TILE_W_MILKSHELFBROKE), W_MILKSHELFBROKE__STATIC, W_MILKSHELFBROKE__STATICRR },
    { "PURPLELAVA", DVPTR(TILE_PURPLELAVA), PURPLELAVA__STATIC, PURPLELAVA__STATICRR },
    { "LAVABUBBLE", DVPTR(TILE_LAVABUBBLE), LAVABUBBLE__STATIC, LAVABUBBLE__STATICRR },
    { "DUKECUTOUT", DVPTR(TILE_DUKECUTOUT), DUKECUTOUT__STATIC, DUKECUTOUT__STATICRR },
    { "TARGET", DVPTR(TILE_TARGET), TARGET__STATIC, TARGET__STATICRR },
    { "GUNPOWDERBARREL", DVPTR(TILE_GUNPOWDERBARREL), GUNPOWDERBARREL__STATIC, GUNPOWDERBARREL__STATICRR },
    { "DUCK", DVPTR(TILE_DUCK), DUCK__STATIC, DUCK__STATICRR },
    { "HATRACK", DVPTR(TILE_HATRACK), HATRACK__STATIC, HATRACK__STATICRR },
    { "DESKLAMP", DVPTR(TILE_DESKLAMP), DESKLAMP__STATIC, DESKLAMP__STATICRR },
    { "COFFEEMACHINE", DVPTR(TILE_COFFEEMACHINE), COFFEEMACHINE__STATIC, COFFEEMACHINE__STATICRR },
    { "CUPS", DVPTR(TILE_CUPS), CUPS__STATIC, CUPS__STATICRR },
    { "GAVALS", DVPTR(TILE_GAVALS), GAVALS__STATIC, GAVALS__STATICRR },
    { "GAVALS2", DVPTR(TILE_GAVALS2), GAVALS2__STATIC, GAVALS2__STATICRR },
    { "POLICELIGHTPOLE", DVPTR(TILE_POLICELIGHTPOLE), POLICELIGHTPOLE__STATIC, POLICELIGHTPOLE__STATICRR },
    { "FLOORBASKET", DVPTR(TILE_FLOORBASKET), FLOORBASKET__STATIC, FLOORBASKET__STATICRR },
    { "PUKE", DVPTR(TILE_PUKE), PUKE__STATIC, PUKE__STATICRR },
    { "DOORTILE23", DVPTR(TILE_DOORTILE23), DOORTILE23__STATIC, DOORTILE23__STATICRR },
    { "TOPSECRET", DVPTR(TILE_TOPSECRET), TOPSECRET__STATIC, TOPSECRET__STATICRR },
    { "SPEAKER", DVPTR(TILE_SPEAKER), SPEAKER__STATIC, SPEAKER__STATICRR },
    { "TEDDYBEAR", DVPTR(TILE_TEDDYBEAR), TEDDYBEAR__STATIC, TEDDYBEAR__STATICRR },
    { "ROBOTDOG", DVPTR(TILE_ROBOTDOG), ROBOTDOG__STATIC, ROBOTDOG__STATICRR },
    { "ROBOTPIRATE", DVPTR(TILE_ROBOTPIRATE), ROBOTPIRATE__STATIC, ROBOTPIRATE__STATICRR },
    { "ROBOTMOUSE", DVPTR(TILE_ROBOTMOUSE), ROBOTMOUSE__STATIC, ROBOTMOUSE__STATICRR },
    { "MAIL", DVPTR(TILE_MAIL), MAIL__STATIC, MAIL__STATICRR },
    { "MAILBAG", DVPTR(TILE_MAILBAG), MAILBAG__STATIC, MAILBAG__STATICRR },
    { "HOTMEAT", DVPTR(TILE_HOTMEAT), HOTMEAT__STATIC, HOTMEAT__STATICRR },
    { "COFFEEMUG", DVPTR(TILE_COFFEEMUG), COFFEEMUG__STATIC, COFFEEMUG__STATICRR },
    { "DONUTS2", DVPTR(TILE_DONUTS2), DONUTS2__STATIC, DONUTS2__STATICRR },
    { "TRIPODCAMERA", DVPTR(TILE_TRIPODCAMERA), TRIPODCAMERA__STATIC, TRIPODCAMERA__STATICRR },
    { "METER", DVPTR(TILE_METER), METER__STATIC, METER__STATICRR },
    { "DESKPHONE", DVPTR(TILE_DESKPHONE), DESKPHONE__STATIC, DESKPHONE__STATICRR },
    { "GUMBALLMACHINE", DVPTR(TILE_GUMBALLMACHINE), GUMBALLMACHINE__STATIC, GUMBALLMACHINE__STATICRR },
    { "GUMBALLMACHINEBROKE", DVPTR(TILE_GUMBALLMACHINEBROKE), GUMBALLMACHINEBROKE__STATIC, GUMBALLMACHINEBROKE__STATICRR },
    { "PAPER", DVPTR(TILE_PAPER), PAPER__STATIC, PAPER__STATICRR },
    { "MACE", DVPTR(TILE_MACE), MACE__STATIC, MACE__STATICRR },
    { "GENERICPOLE2", DVPTR(TILE_GENERICPOLE2), GENERICPOLE2__STATIC, GENERICPOLE2__STATICRR },
    { "XXXSTACY", DVPTR(TILE_XXXSTACY), XXXSTACY__STATIC, XXXSTACY__STATICRR },
    { "WETFLOOR", DVPTR(TILE_WETFLOOR), WETFLOOR__STATIC, WETFLOOR__STATICRR },
    { "BROOM", DVPTR(TILE_BROOM), BROOM__STATIC, BROOM__STATICRR },
    { "MOP", DVPTR(TILE_MOP), MOP__STATIC, MOP__STATICRR },
    { "LETTER", DVPTR(TILE_LETTER), LETTER__STATIC, 0 },
    { "PIRATE1A", DVPTR(TILE_PIRATE1A), PIRATE1A__STATIC, PIRATE1A__STATICRR },
    { "PIRATE4A", DVPTR(TILE_PIRATE4A), PIRATE4A__STATIC, PIRATE4A__STATICRR },
    { "PIRATE2A", DVPTR(TILE_PIRATE2A), PIRATE2A__STATIC, PIRATE2A__STATICRR },
    { "PIRATE5A", DVPTR(TILE_PIRATE5A), PIRATE5A__STATIC, PIRATE5A__STATICRR },
    { "PIRATE3A", DVPTR(TILE_PIRATE3A), PIRATE3A__STATIC, PIRATE3A__STATICRR },
    { "PIRATE6A", DVPTR(TILE_PIRATE6A), PIRATE6A__STATIC, PIRATE6A__STATICRR },
    { "PIRATEHALF", DVPTR(TILE_PIRATEHALF), PIRATEHALF__STATIC, PIRATEHALF__STATICRR },
    { "CHESTOFGOLD", DVPTR(TILE_CHESTOFGOLD), CHESTOFGOLD__STATIC, CHESTOFGOLD__STATICRR },
    { "SIDEBOLT1", DVPTR(TILE_SIDEBOLT1), SIDEBOLT1__STATIC, SIDEBOLT1__STATICRR },
    { "HEADLAMP", DVPTR(TILE_HEADLAMP), HEADLAMP__STATIC, HEADLAMP__STATICRR },
    { "TAMPON", DVPTR(TILE_TAMPON), TAMPON__STATIC, TAMPON__STATICRR },
    { "SKINNEDCHICKEN", DVPTR(TILE_SKINNEDCHICKEN), SKINNEDCHICKEN__STATIC, SKINNEDCHICKEN__STATICRR },
    { "FEATHEREDCHICKEN", DVPTR(TILE_FEATHEREDCHICKEN), FEATHEREDCHICKEN__STATIC, FEATHEREDCHICKEN__STATICRR },
    { "ROBOTDOG2", DVPTR(TILE_ROBOTDOG2), ROBOTDOG2__STATIC, ROBOTDOG2__STATICRR },
    { "JOLLYMEAL", DVPTR(TILE_JOLLYMEAL), JOLLYMEAL__STATIC, JOLLYMEAL__STATICRR },
    { "DUKEBURGER", DVPTR(TILE_DUKEBURGER), DUKEBURGER__STATIC, DUKEBURGER__STATICRR },
    { "SHOPPINGCART", DVPTR(TILE_SHOPPINGCART), SHOPPINGCART__STATIC, SHOPPINGCART__STATICRR },
    { "CANWITHSOMETHING2", DVPTR(TILE_CANWITHSOMETHING2), CANWITHSOMETHING2__STATIC, CANWITHSOMETHING2__STATICRR },
    { "CANWITHSOMETHING3", DVPTR(TILE_CANWITHSOMETHING3), CANWITHSOMETHING3__STATIC, CANWITHSOMETHING3__STATICRR },
    { "CANWITHSOMETHING4", DVPTR(TILE_CANWITHSOMETHING4), CANWITHSOMETHING4__STATIC, CANWITHSOMETHING4__STATICRR },
    { "SNAKEP", DVPTR(TILE_SNAKEP), SNAKEP__STATIC, SNAKEP__STATICRR },
    { "DOLPHIN1", DVPTR(TILE_DOLPHIN1), DOLPHIN1__STATIC, DOLPHIN1__STATICRR },
    { "DOLPHIN2", DVPTR(TILE_DOLPHIN2), DOLPHIN2__STATIC, DOLPHIN2__STATICRR },
    { "NEWBEAST", DVPTR(TILE_NEWBEAST), NEWBEAST__STATIC, 0 },
    { "NEWBEASTSTAYPUT", DVPTR(TILE_NEWBEASTSTAYPUT), NEWBEASTSTAYPUT__STATIC, 0 },
    { "NEWBEASTJUMP", DVPTR(TILE_NEWBEASTJUMP), NEWBEASTJUMP__STATIC, 0 },
    { "NEWBEASTHANG", DVPTR(TILE_NEWBEASTHANG), NEWBEASTHANG__STATIC, 0 },
    { "NEWBEASTHANGDEAD", DVPTR(TILE_NEWBEASTHANGDEAD), NEWBEASTHANGDEAD__STATIC, 0 },
    { "BOSS4", DVPTR(TILE_BOSS4), BOSS4__STATIC, BOSS4__STATICRR },
    { "BOSS4STAYPUT", DVPTR(TILE_BOSS4STAYPUT), BOSS4STAYPUT__STATIC, 0 },
    { "FEM10", DVPTR(TILE_FEM10), FEM10__STATIC, FEM10__STATICRR },
    { "TOUGHGAL", DVPTR(TILE_TOUGHGAL), TOUGHGAL__STATIC, TOUGHGAL__STATICRR },
    { "MAN", DVPTR(TILE_MAN), MAN__STATIC, MAN__STATICRR },
    { "MAN2", DVPTR(TILE_MAN2), MAN2__STATIC, MAN2__STATICRR },
    { "WOMAN", DVPTR(TILE_WOMAN), WOMAN__STATIC, WOMAN__STATICRR },
    { "PLEASEWAIT", DVPTR(TILE_PLEASEWAIT), PLEASEWAIT__STATIC, PLEASEWAIT__STATICRR },
    { "NATURALLIGHTNING", DVPTR(TILE_NATURALLIGHTNING), NATURALLIGHTNING__STATIC, 0 },
    { "WEATHERWARN", DVPTR(TILE_WEATHERWARN), WEATHERWARN__STATIC, 0 },
    { "DUKETAG", DVPTR(TILE_DUKETAG), DUKETAG__STATIC, DUKETAG__STATICRR },
    { "SIGN1", DVPTR(TILE_SIGN1), SIGN1__STATIC, SIGN1__STATICRR },
    { "SIGN2", DVPTR(TILE_SIGN2), SIGN2__STATIC, SIGN2__STATICRR },
    { "JURYGUY", DVPTR(TILE_JURYGUY), JURYGUY__STATIC, JURYGUY__STATICRR },
    { "RPG2SPRITE", DVPTR(TILE_RPG2SPRITE), 0, RPG2SPRITE__STATICRR },
    { "DESTRUCTO", DVPTR(TILE_DESTRUCTO), 0, DESTRUCTO__STATICRR },
    { "GUTMETER", DVPTR(TILE_GUTMETER), 0, GUTMETER__STATICRR },
    { "SOUNDFX", DVPTR(TILE_SOUNDFX), 0, SOUNDFX__STATICRR },
    { "MOTOAMMO", DVPTR(TILE_MOTOAMMO), 0, MOTOAMMO__STATICRR },
    { "UFOBEAM", DVPTR(TILE_UFOBEAM), 0, UFOBEAM__STATICRR },
    { "CDPLAYER", DVPTR(TILE_CDPLAYER), 0, CDPLAYER__STATICRR },
    { "GUTMETER_LIGHT1", DVPTR(TILE_GUTMETER_LIGHT1), 0, GUTMETER_LIGHT1__STATICRR },
    { "GUTMETER_LIGHT2", DVPTR(TILE_GUTMETER_LIGHT2), 0, GUTMETER_LIGHT2__STATICRR },
    { "GUTMETER_LIGHT3", DVPTR(TILE_GUTMETER_LIGHT3), 0, GUTMETER_LIGHT3__STATICRR },
    { "GUTMETER_LIGHT4", DVPTR(TILE_GUTMETER_LIGHT4), 0, GUTMETER_LIGHT4__STATICRR },
    { "AMMO_ICON", DVPTR(TILE_AMMO_ICON), 0, AMMO_ICON__STATICRR },
    { "MUD", DVPTR(TILE_MUD), 0, MUD__STATICRR },
    { "EXPLOSION3", DVPTR(TILE_EXPLOSION3), 0, EXPLOSION3__STATICRR },
    { "WEAPONBAR", DVPTR(TILE_WEAPONBAR), 0, WEAPONBAR__STATICRR },
    { "RPG2", DVPTR(TILE_RPG2), 0, RPG2__STATICRR },
    { "POPCORN", DVPTR(TILE_POPCORN), 0, POPCORN__STATICRR },
    { "LANEPICS", DVPTR(TILE_LANEPICS), 0, LANEPICS__STATICRR },
    { "SHOTGUNSHELLS", DVPTR(TILE_SHOTGUNSHELLS), 0, SHOTGUNSHELLS__STATICRR },
    { "CIRCLESTUCK", DVPTR(TILE_CIRCLESTUCK), 0, CIRCLESTUCK__STATICRR },
    { "LUMBERBLADE", DVPTR(TILE_LUMBERBLADE), 0, LUMBERBLADE__STATICRR },
    { "BOWLINGBALLH", DVPTR(TILE_BOWLINGBALLH), 0, BOWLINGBALLH__STATICRR },
    { "BOWLINGBALL", DVPTR(TILE_BOWLINGBALL), 0, BOWLINGBALL__STATICRR },
    { "BOWLINGBALLSPRITE", DVPTR(TILE_BOWLINGBALLSPRITE), 0, BOWLINGBALLSPRITE__STATICRR },
    { "POWDERH", DVPTR(TILE_POWDERH), 0, POWDERH__STATICRR },
    { "OWHIP", DVPTR(TILE_OWHIP), 0, OWHIP__STATICRR },
    { "UWHIP", DVPTR(TILE_UWHIP), 0, UWHIP__STATICRR },
    { "RPGGUN2", DVPTR(TILE_RPGGUN2), 0, RPGGUN2__STATICRR },
    { "SLINGBLADE", DVPTR(TILE_SLINGBLADE), 0, SLINGBLADE__STATICRR },
    { "MOTOGUN", DVPTR(TILE_MOTOGUN), 0, MOTOGUN__STATICRR },
    { "MOTOHIT", DVPTR(TILE_MOTOHIT), 0, MOTOHIT__STATICRR },
    { "BOATHIT", DVPTR(TILE_BOATHIT), 0, BOATHIT__STATICRR },
    { "EMPTYBIKE", DVPTR(TILE_EMPTYBIKE), 0, EMPTYBIKE__STATICRR },
    { "EMPTYBOAT", DVPTR(TILE_EMPTYBOAT), 0, EMPTYBOAT__STATICRR },
    { "MULTISWITCH2", DVPTR(TILE_MULTISWITCH2), 0, MULTISWITCH2__STATICRR },
    { "BOATAMMO", DVPTR(TILE_BOATAMMO), 0, BOATAMMO__STATICRR },
    { "BOULDER", DVPTR(TILE_BOULDER), 0, BOULDER__STATICRR },
    { "BOULDER1", DVPTR(TILE_BOULDER1), 0, BOULDER1__STATICRR },
    { "TORNADO", DVPTR(TILE_TORNADO), 0, TORNADO__STATICRR },
    { "CHEERBOMB", DVPTR(TILE_CHEERBOMB), 0, CHEERBOMB__STATICRR },
    { "CHEERBLADE", DVPTR(TILE_CHEERBLADE), 0, CHEERBLADE__STATICRR },
    { "DOGATTACK", DVPTR(TILE_DOGATTACK), 0, DOGATTACK__STATICRR },
    { "BILLYWALK", DVPTR(TILE_BILLYWALK), 0, BILLYWALK__STATICRR },
    { "BILLYDIE", DVPTR(TILE_BILLYDIE), 0, BILLYDIE__STATICRR },
    { "BILLYCOCK", DVPTR(TILE_BILLYCOCK), 0, BILLYCOCK__STATICRR },
    { "BILLYRAY", DVPTR(TILE_BILLYRAY), 0, BILLYRAY__STATICRR },
    { "BILLYRAYSTAYPUT", DVPTR(TILE_BILLYRAYSTAYPUT), 0, BILLYRAYSTAYPUT__STATICRR },
    { "BILLYBUT", DVPTR(TILE_BILLYBUT), 0, BILLYBUT__STATICRR },
    { "BILLYSCRATCH", DVPTR(TILE_BILLYSCRATCH), 0, BILLYSCRATCH__STATICRR },
    { "BILLYSNIFF", DVPTR(TILE_BILLYSNIFF), 0, BILLYSNIFF__STATICRR },
    { "BILLYWOUND", DVPTR(TILE_BILLYWOUND), 0, BILLYWOUND__STATICRR },
    { "BILLYGORE", DVPTR(TILE_BILLYGORE), 0, BILLYGORE__STATICRR },
    { "BILLYJIBA", DVPTR(TILE_BILLYJIBA), 0, BILLYJIBA__STATICRR },
    { "BILLYJIBB", DVPTR(TILE_BILLYJIBB), 0, BILLYJIBB__STATICRR },
    { "BRAYSNIPER", DVPTR(TILE_BRAYSNIPER), 0, BRAYSNIPER__STATICRR },
    { "DOGRUN", DVPTR(TILE_DOGRUN), 0, DOGRUN__STATICRR },
    { "DOGDIE", DVPTR(TILE_DOGDIE), 0, DOGDIE__STATICRR },
    { "DOGDEAD", DVPTR(TILE_DOGDEAD), 0, DOGDEAD__STATICRR },
    { "DOGBARK", DVPTR(TILE_DOGBARK), 0, DOGBARK__STATICRR },
    { "LTH", DVPTR(TILE_LTH), 0, LTH__STATICRR },
    { "LTHSTRAFE", DVPTR(TILE_LTHSTRAFE), 0, LTHSTRAFE__STATICRR },
    { "HULKHANG", DVPTR(TILE_HULKHANG), 0, HULKHANG__STATICRR },
    { "HULKHANGDEAD", DVPTR(TILE_HULKHANGDEAD), 0, HULKHANGDEAD__STATICRR },
    { "HULKJUMP", DVPTR(TILE_HULKJUMP), 0, HULKJUMP__STATICRR },
    { "LTHLOAD", DVPTR(TILE_LTHLOAD), 0, LTHLOAD__STATICRR },
    { "LTHDIE", DVPTR(TILE_LTHDIE), 0, LTHDIE__STATICRR },
    { "BUBBASCRATCH", DVPTR(TILE_BUBBASCRATCH), 0, BUBBASCRATCH__STATICRR },
    { "BUBBANOSE", DVPTR(TILE_BUBBANOSE), 0, BUBBANOSE__STATICRR },
    { "BUBBAPISS", DVPTR(TILE_BUBBAPISS), 0, BUBBAPISS__STATICRR },
    { "BUBBASTAND", DVPTR(TILE_BUBBASTAND), 0, BUBBASTAND__STATICRR },
    { "BUBBAOUCH", DVPTR(TILE_BUBBAOUCH), 0, BUBBAOUCH__STATICRR },
    { "BUBBADIE", DVPTR(TILE_BUBBADIE), 0, BUBBADIE__STATICRR },
    { "BUBBADEAD", DVPTR(TILE_BUBBADEAD), 0, BUBBADEAD__STATICRR },
    { "HULK", DVPTR(TILE_HULK), 0, HULK__STATICRR },
    { "HULKSTAYPUT", DVPTR(TILE_HULKSTAYPUT), 0, HULKSTAYPUT__STATICRR },
    { "HULKA", DVPTR(TILE_HULKA), 0, HULKA__STATICRR },
    { "HULKB", DVPTR(TILE_HULKB), 0, HULKB__STATICRR },
    { "HULKC", DVPTR(TILE_HULKC), 0, HULKC__STATICRR },
    { "HULKJIBA", DVPTR(TILE_HULKJIBA), 0, HULKJIBA__STATICRR },
    { "HULKJIBB", DVPTR(TILE_HULKJIBB), 0, HULKJIBB__STATICRR },
    { "HULKJIBC", DVPTR(TILE_HULKJIBC), 0, HULKJIBC__STATICRR },
    { "SBSWIPE", DVPTR(TILE_SBSWIPE), 0, SBSWIPE__STATICRR },
    { "SBPAIN", DVPTR(TILE_SBPAIN), 0, SBPAIN__STATICRR },
    { "SBDIE", DVPTR(TILE_SBDIE), 0, SBDIE__STATICRR },
    { "HEN", DVPTR(TILE_HEN), 0, HEN__STATICRR },
    { "HENSTAYPUT", DVPTR(TILE_HENSTAYPUT), 0, HENSTAYPUT__STATICRR },
    { "HENSTAND", DVPTR(TILE_HENSTAND), 0, HENSTAND__STATICRR },
    { "PIG", DVPTR(TILE_PIG), 0, PIG__STATICRR },
    { "PIGSTAYPUT", DVPTR(TILE_PIGSTAYPUT), 0, PIGSTAYPUT__STATICRR },
    { "PIGEAT", DVPTR(TILE_PIGEAT), 0, PIGEAT__STATICRR },
    { "SBMOVE", DVPTR(TILE_SBMOVE), 0, SBMOVE__STATICRR },
    { "SBSPIT", DVPTR(TILE_SBSPIT), 0, SBSPIT__STATICRR },
    { "SBDIP", DVPTR(TILE_SBDIP), 0, SBDIP__STATICRR },
    { "MINION", DVPTR(TILE_MINION), 0, MINION__STATICRR },
    { "MINIONSTAYPUT", DVPTR(TILE_MINIONSTAYPUT), 0, MINIONSTAYPUT__STATICRR },
    { "UFO1", DVPTR(TILE_UFO1), 0, UFO1__STATICRR },
    { "UFO2", DVPTR(TILE_UFO2), 0, UFO2__STATICRR },
    { "UFO3", DVPTR(TILE_UFO3), 0, UFO3__STATICRR },
    { "UFO4", DVPTR(TILE_UFO4), 0, UFO4__STATICRR },
    { "UFO5", DVPTR(TILE_UFO5), 0, UFO5__STATICRR },
    { "MINJIBA", DVPTR(TILE_MINJIBA), 0, MINJIBA__STATICRR },
    { "MINJIBB", DVPTR(TILE_MINJIBB), 0, MINJIBB__STATICRR },
    { "MINJIBC", DVPTR(TILE_MINJIBC), 0, MINJIBC__STATICRR },
    { "COW", DVPTR(TILE_COW), 0, COW__STATICRR },
    { "COOT", DVPTR(TILE_COOT), 0, COOT__STATICRR },
    { "COOTSTAYPUT", DVPTR(TILE_COOTSTAYPUT), 0, COOTSTAYPUT__STATICRR },
    { "COOTSHOOT", DVPTR(TILE_COOTSHOOT), 0, COOTSHOOT__STATICRR },
    { "COOTDIE", DVPTR(TILE_COOTDIE), 0, COOTDIE__STATICRR },
    { "COOTDUCK", DVPTR(TILE_COOTDUCK), 0, COOTDUCK__STATICRR },
    { "COOTPAIN", DVPTR(TILE_COOTPAIN), 0, COOTPAIN__STATICRR },
    { "COOTTRANS", DVPTR(TILE_COOTTRANS), 0, COOTTRANS__STATICRR },
    { "COOTGETUP", DVPTR(TILE_COOTGETUP), 0, COOTGETUP__STATICRR },
    { "COOTJIBA", DVPTR(TILE_COOTJIBA), 0, COOTJIBA__STATICRR },
    { "COOTJIBB", DVPTR(TILE_COOTJIBB), 0, COOTJIBB__STATICRR },
    { "COOTJIBC", DVPTR(TILE_COOTJIBC), 0, COOTJIBC__STATICRR },
    { "VIXEN", DVPTR(TILE_VIXEN), 0, VIXEN__STATICRR },
    { "VIXENPAIN", DVPTR(TILE_VIXENPAIN), 0, VIXENPAIN__STATICRR },
    { "VIXENDIE", DVPTR(TILE_VIXENDIE), 0, VIXENDIE__STATICRR },
    { "VIXENSHOOT", DVPTR(TILE_VIXENSHOOT), 0, VIXENSHOOT__STATICRR },
    { "VIXENWDN", DVPTR(TILE_VIXENWDN), 0, VIXENWDN__STATICRR },
    { "VIXENWUP", DVPTR(TILE_VIXENWUP), 0, VIXENWUP__STATICRR },
    { "VIXENKICK", DVPTR(TILE_VIXENKICK), 0, VIXENKICK__STATICRR },
    { "VIXENTELE", DVPTR(TILE_VIXENTELE), 0, VIXENTELE__STATICRR },
    { "VIXENTEAT", DVPTR(TILE_VIXENTEAT), 0, VIXENTEAT__STATICRR },
    { "BIKEJIBA", DVPTR(TILE_BIKEJIBA), 0, BIKEJIBA__STATICRR },
    { "BIKEJIBB", DVPTR(TILE_BIKEJIBB), 0, BIKEJIBB__STATICRR },
    { "BIKEJIBC", DVPTR(TILE_BIKEJIBC), 0, BIKEJIBC__STATICRR },
    { "BIKERB", DVPTR(TILE_BIKERB), 0, BIKERB__STATICRR },
    { "BIKERBV2", DVPTR(TILE_BIKERBV2), 0, BIKERBV2__STATICRR },
    { "BIKER", DVPTR(TILE_BIKER), 0, BIKER__STATICRR },
    { "BIKERJIBA", DVPTR(TILE_BIKERJIBA), 0, BIKERJIBA__STATICRR },
    { "BIKERJIBB", DVPTR(TILE_BIKERJIBB), 0, BIKERJIBB__STATICRR },
    { "BIKERJIBC", DVPTR(TILE_BIKERJIBC), 0, BIKERJIBC__STATICRR },
    { "BIKERJIBD", DVPTR(TILE_BIKERJIBD), 0, BIKERJIBD__STATICRR },
    { "MAKEOUT", DVPTR(TILE_MAKEOUT), 0, MAKEOUT__STATICRR },
    { "CHEERB", DVPTR(TILE_CHEERB), 0, CHEERB__STATICRR },
    { "CHEER", DVPTR(TILE_CHEER), 0, CHEER__STATICRR },
    { "CHEERSTAYPUT", DVPTR(TILE_CHEERSTAYPUT), 0, CHEERSTAYPUT__STATICRR },
    { "CHEERJIBA", DVPTR(TILE_CHEERJIBA), 0, CHEERJIBA__STATICRR },
    { "CHEERJIBB", DVPTR(TILE_CHEERJIBB), 0, CHEERJIBB__STATICRR },
    { "CHEERJIBC", DVPTR(TILE_CHEERJIBC), 0, CHEERJIBC__STATICRR },
    { "CHEERJIBD", DVPTR(TILE_CHEERJIBD), 0, CHEERJIBD__STATICRR },
    { "FBOATJIBA", DVPTR(TILE_FBOATJIBA), 0, FBOATJIBA__STATICRR },
    { "FBOATJIBB", DVPTR(TILE_FBOATJIBB), 0, FBOATJIBB__STATICRR },
    { "COOTPLAY", DVPTR(TILE_COOTPLAY), 0, COOTPLAY__STATICRR },
    { "BILLYPLAY", DVPTR(TILE_BILLYPLAY), 0, BILLYPLAY__STATICRR },
    { "MINIONBOAT", DVPTR(TILE_MINIONBOAT), 0, MINIONBOAT__STATICRR },
    { "HULKBOAT", DVPTR(TILE_HULKBOAT), 0, HULKBOAT__STATICRR },
    { "CHEERBOAT", DVPTR(TILE_CHEERBOAT), 0, CHEERBOAT__STATICRR },
    { "RRTILE7274", DVPTR(TILE_RRTILE7274), 0, RRTILE7274__STATICRR },
    { "RABBIT", DVPTR(TILE_RABBIT), 0, RABBIT__STATICRR },
    { "RABBITJIBA", DVPTR(TILE_RABBITJIBA), 0, RABBITJIBA__STATICRR },
    { "RABBITJIBB", DVPTR(TILE_RABBITJIBB), 0, RABBITJIBB__STATICRR },
    { "RABBITJIBC", DVPTR(TILE_RABBITJIBC), 0, RABBITJIBC__STATICRR },
    { "ROCK", DVPTR(TILE_ROCK), 0, ROCK__STATICRR },
    { "ROCK2", DVPTR(TILE_ROCK2), 0, ROCK2__STATICRR },
    { "MAMACLOUD", DVPTR(TILE_MAMACLOUD), 0, MAMACLOUD__STATICRR },
    { "MAMA", DVPTR(TILE_MAMA), 0, MAMA__STATICRR },
    { "MAMAJIBA", DVPTR(TILE_MAMAJIBA), 0, MAMAJIBA__STATICRR },
    { "MAMAJIBB", DVPTR(TILE_MAMAJIBB), 0, MAMAJIBB__STATICRR },
    { NULL, NULL, -1, -1 },
};

int32_t TILE_SECTOREFFECTOR = SECTOREFFECTOR__STATIC;
int32_t TILE_ACTIVATOR = ACTIVATOR__STATIC;
int32_t TILE_TOUCHPLATE = TOUCHPLATE__STATIC;
int32_t TILE_ACTIVATORLOCKED = ACTIVATORLOCKED__STATIC;
int32_t TILE_MUSICANDSFX = MUSICANDSFX__STATIC;
int32_t TILE_LOCATORS = LOCATORS__STATIC;
int32_t TILE_CYCLER = CYCLER__STATIC;
int32_t TILE_MASTERSWITCH = MASTERSWITCH__STATIC;
int32_t TILE_RESPAWN = RESPAWN__STATIC;
int32_t TILE_GPSPEED = GPSPEED__STATIC;
int32_t TILE_FOF = FOF__STATIC;
int32_t TILE_ARROW = ARROW__STATIC;
int32_t TILE_FIRSTGUNSPRITE = FIRSTGUNSPRITE__STATIC;
int32_t TILE_CHAINGUNSPRITE = CHAINGUNSPRITE__STATIC;
int32_t TILE_RPGSPRITE = RPGSPRITE__STATIC;
int32_t TILE_FREEZESPRITE = FREEZESPRITE__STATIC;
int32_t TILE_SHRINKERSPRITE = SHRINKERSPRITE__STATIC;
int32_t TILE_HEAVYHBOMB = HEAVYHBOMB__STATIC;
int32_t TILE_TRIPBOMBSPRITE = TRIPBOMBSPRITE__STATIC;
int32_t TILE_SHOTGUNSPRITE = SHOTGUNSPRITE__STATIC;
int32_t TILE_DEVISTATORSPRITE = DEVISTATORSPRITE__STATIC;
int32_t TILE_HEALTHBOX = HEALTHBOX__STATIC;
int32_t TILE_AMMOBOX = AMMOBOX__STATIC;
int32_t TILE_GROWSPRITEICON = GROWSPRITEICON__STATIC;
int32_t TILE_INVENTORYBOX = INVENTORYBOX__STATIC;
int32_t TILE_FREEZEAMMO = FREEZEAMMO__STATIC;
int32_t TILE_AMMO = AMMO__STATIC;
int32_t TILE_BATTERYAMMO = BATTERYAMMO__STATIC;
int32_t TILE_DEVISTATORAMMO = DEVISTATORAMMO__STATIC;
int32_t TILE_RPGAMMO = RPGAMMO__STATIC;
int32_t TILE_GROWAMMO = GROWAMMO__STATIC;
int32_t TILE_CRYSTALAMMO = CRYSTALAMMO__STATIC;
int32_t TILE_HBOMBAMMO = HBOMBAMMO__STATIC;
int32_t TILE_AMMOLOTS = AMMOLOTS__STATIC;
int32_t TILE_SHOTGUNAMMO = SHOTGUNAMMO__STATIC;
int32_t TILE_COLA = COLA__STATIC;
int32_t TILE_SIXPAK = SIXPAK__STATIC;
int32_t TILE_FIRSTAID = FIRSTAID__STATIC;
int32_t TILE_SHIELD = SHIELD__STATIC;
int32_t TILE_STEROIDS = STEROIDS__STATIC;
int32_t TILE_AIRTANK = AIRTANK__STATIC;
int32_t TILE_JETPACK = JETPACK__STATIC;
int32_t TILE_HEATSENSOR = HEATSENSOR__STATIC;
int32_t TILE_ACCESSCARD = ACCESSCARD__STATIC;
int32_t TILE_BOOTS = BOOTS__STATIC;
int32_t TILE_MIRRORBROKE = MIRRORBROKE__STATIC;
int32_t TILE_CLOUDYOCEAN = CLOUDYOCEAN__STATIC;
int32_t TILE_CLOUDYSKIES = CLOUDYSKIES__STATIC;
int32_t TILE_MOONSKY1 = MOONSKY1__STATIC;
int32_t TILE_MOONSKY2 = MOONSKY2__STATIC;
int32_t TILE_MOONSKY3 = MOONSKY3__STATIC;
int32_t TILE_MOONSKY4 = MOONSKY4__STATIC;
int32_t TILE_BIGORBIT1 = BIGORBIT1__STATIC;
int32_t TILE_BIGORBIT2 = BIGORBIT2__STATIC;
int32_t TILE_BIGORBIT3 = BIGORBIT3__STATIC;
int32_t TILE_BIGORBIT4 = BIGORBIT4__STATIC;
int32_t TILE_BIGORBIT5 = BIGORBIT5__STATIC;
int32_t TILE_LA = LA__STATIC;
int32_t TILE_REDSKY1 = REDSKY1__STATIC;
int32_t TILE_REDSKY2 = REDSKY2__STATIC;
int32_t TILE_ATOMICHEALTH = ATOMICHEALTH__STATIC;
int32_t TILE_TECHLIGHT2 = TECHLIGHT2__STATIC;
int32_t TILE_TECHLIGHTBUST2 = TECHLIGHTBUST2__STATIC;
int32_t TILE_TECHLIGHT4 = TECHLIGHT4__STATIC;
int32_t TILE_TECHLIGHTBUST4 = TECHLIGHTBUST4__STATIC;
int32_t TILE_WALLLIGHT4 = WALLLIGHT4__STATIC;
int32_t TILE_WALLLIGHTBUST4 = WALLLIGHTBUST4__STATIC;
int32_t TILE_ACCESSSWITCH = ACCESSSWITCH__STATIC;
int32_t TILE_SLOTDOOR = SLOTDOOR__STATIC;
int32_t TILE_LIGHTSWITCH = LIGHTSWITCH__STATIC;
int32_t TILE_SPACEDOORSWITCH = SPACEDOORSWITCH__STATIC;
int32_t TILE_SPACELIGHTSWITCH = SPACELIGHTSWITCH__STATIC;
int32_t TILE_FRANKENSTINESWITCH = FRANKENSTINESWITCH__STATIC;
int32_t TILE_NUKEBUTTON = NUKEBUTTON__STATIC;
int32_t TILE_MULTISWITCH = MULTISWITCH__STATIC;
int32_t TILE_DOORTILE5 = DOORTILE5__STATIC;
int32_t TILE_DOORTILE6 = DOORTILE6__STATIC;
int32_t TILE_DOORTILE1 = DOORTILE1__STATIC;
int32_t TILE_DOORTILE2 = DOORTILE2__STATIC;
int32_t TILE_DOORTILE3 = DOORTILE3__STATIC;
int32_t TILE_DOORTILE4 = DOORTILE4__STATIC;
int32_t TILE_DOORTILE7 = DOORTILE7__STATIC;
int32_t TILE_DOORTILE8 = DOORTILE8__STATIC;
int32_t TILE_DOORTILE9 = DOORTILE9__STATIC;
int32_t TILE_DOORTILE10 = DOORTILE10__STATIC;
int32_t TILE_DOORSHOCK = DOORSHOCK__STATIC;
int32_t TILE_DIPSWITCH = DIPSWITCH__STATIC;
int32_t TILE_DIPSWITCH2 = DIPSWITCH2__STATIC;
int32_t TILE_TECHSWITCH = TECHSWITCH__STATIC;
int32_t TILE_DIPSWITCH3 = DIPSWITCH3__STATIC;
int32_t TILE_ACCESSSWITCH2 = ACCESSSWITCH2__STATIC;
int32_t TILE_REFLECTWATERTILE = REFLECTWATERTILE__STATIC;
int32_t TILE_FLOORSLIME = FLOORSLIME__STATIC;
int32_t TILE_BIGFORCE = BIGFORCE__STATIC;
int32_t TILE_EPISODE = EPISODE__STATIC;
int32_t TILE_MASKWALL9 = MASKWALL9__STATIC;
int32_t TILE_W_LIGHT = W_LIGHT__STATIC;
int32_t TILE_SCREENBREAK1 = SCREENBREAK1__STATIC;
int32_t TILE_SCREENBREAK2 = SCREENBREAK2__STATIC;
int32_t TILE_SCREENBREAK3 = SCREENBREAK3__STATIC;
int32_t TILE_SCREENBREAK4 = SCREENBREAK4__STATIC;
int32_t TILE_SCREENBREAK5 = SCREENBREAK5__STATIC;
int32_t TILE_SCREENBREAK6 = SCREENBREAK6__STATIC;
int32_t TILE_SCREENBREAK7 = SCREENBREAK7__STATIC;
int32_t TILE_SCREENBREAK8 = SCREENBREAK8__STATIC;
int32_t TILE_SCREENBREAK9 = SCREENBREAK9__STATIC;
int32_t TILE_SCREENBREAK10 = SCREENBREAK10__STATIC;
int32_t TILE_SCREENBREAK11 = SCREENBREAK11__STATIC;
int32_t TILE_SCREENBREAK12 = SCREENBREAK12__STATIC;
int32_t TILE_SCREENBREAK13 = SCREENBREAK13__STATIC;
int32_t TILE_MASKWALL1 = MASKWALL1__STATIC;
int32_t TILE_W_TECHWALL1 = W_TECHWALL1__STATIC;
int32_t TILE_W_TECHWALL2 = W_TECHWALL2__STATIC;
int32_t TILE_W_TECHWALL15 = W_TECHWALL15__STATIC;
int32_t TILE_W_TECHWALL3 = W_TECHWALL3__STATIC;
int32_t TILE_W_TECHWALL4 = W_TECHWALL4__STATIC;
int32_t TILE_W_TECHWALL10 = W_TECHWALL10__STATIC;
int32_t TILE_W_TECHWALL16 = W_TECHWALL16__STATIC;
int32_t TILE_WATERTILE2 = WATERTILE2__STATIC;
int32_t TILE_BPANNEL1 = BPANNEL1__STATIC;
int32_t TILE_PANNEL1 = PANNEL1__STATIC;
int32_t TILE_PANNEL2 = PANNEL2__STATIC;
int32_t TILE_WATERTILE = WATERTILE__STATIC;
int32_t TILE_STATIC = STATIC__STATIC;
int32_t TILE_W_SCREENBREAK = W_SCREENBREAK__STATIC;
int32_t TILE_W_HITTECHWALL3 = W_HITTECHWALL3__STATIC;
int32_t TILE_W_HITTECHWALL4 = W_HITTECHWALL4__STATIC;
int32_t TILE_W_HITTECHWALL2 = W_HITTECHWALL2__STATIC;
int32_t TILE_W_HITTECHWALL1 = W_HITTECHWALL1__STATIC;
int32_t TILE_MASKWALL10 = MASKWALL10__STATIC;
int32_t TILE_MASKWALL11 = MASKWALL11__STATIC;
int32_t TILE_DOORTILE22 = DOORTILE22__STATIC;
int32_t TILE_FANSPRITE = FANSPRITE__STATIC;
int32_t TILE_FANSPRITEBROKE = FANSPRITEBROKE__STATIC;
int32_t TILE_FANSHADOW = FANSHADOW__STATIC;
int32_t TILE_FANSHADOWBROKE = FANSHADOWBROKE__STATIC;
int32_t TILE_DOORTILE18 = DOORTILE18__STATIC;
int32_t TILE_DOORTILE19 = DOORTILE19__STATIC;
int32_t TILE_DOORTILE20 = DOORTILE20__STATIC;
int32_t TILE_SATELLITE = SATELLITE__STATIC;
int32_t TILE_VIEWSCREEN2 = VIEWSCREEN2__STATIC;
int32_t TILE_VIEWSCREENBROKE = VIEWSCREENBROKE__STATIC;
int32_t TILE_VIEWSCREEN = VIEWSCREEN__STATIC;
int32_t TILE_GLASS = GLASS__STATIC;
int32_t TILE_GLASS2 = GLASS2__STATIC;
int32_t TILE_STAINGLASS1 = STAINGLASS1__STATIC;
int32_t TILE_MASKWALL5 = MASKWALL5__STATIC;
int32_t TILE_SATELITE = SATELITE__STATIC;
int32_t TILE_FUELPOD = FUELPOD__STATIC;
int32_t TILE_SLIMEPIPE = SLIMEPIPE__STATIC;
int32_t TILE_CRACK1 = CRACK1__STATIC;
int32_t TILE_CRACK2 = CRACK2__STATIC;
int32_t TILE_CRACK3 = CRACK3__STATIC;
int32_t TILE_CRACK4 = CRACK4__STATIC;
int32_t TILE_FOOTPRINTS = FOOTPRINTS__STATIC;
int32_t TILE_DOMELITE = DOMELITE__STATIC;
int32_t TILE_CAMERAPOLE = CAMERAPOLE__STATIC;
int32_t TILE_CHAIR1 = CHAIR1__STATIC;
int32_t TILE_CHAIR2 = CHAIR2__STATIC;
int32_t TILE_BROKENCHAIR = BROKENCHAIR__STATIC;
int32_t TILE_MIRROR = MIRROR__STATIC;
int32_t TILE_WATERFOUNTAIN = WATERFOUNTAIN__STATIC;
int32_t TILE_WATERFOUNTAINBROKE = WATERFOUNTAINBROKE__STATIC;
int32_t TILE_FEMMAG1 = FEMMAG1__STATIC;
int32_t TILE_TOILET = TOILET__STATIC;
int32_t TILE_STALL = STALL__STATIC;
int32_t TILE_STALLBROKE = STALLBROKE__STATIC;
int32_t TILE_FEMMAG2 = FEMMAG2__STATIC;
int32_t TILE_REACTOR2 = REACTOR2__STATIC;
int32_t TILE_REACTOR2BURNT = REACTOR2BURNT__STATIC;
int32_t TILE_REACTOR2SPARK = REACTOR2SPARK__STATIC;
int32_t TILE_GRATE1 = GRATE1__STATIC;
int32_t TILE_BGRATE1 = BGRATE1__STATIC;
int32_t TILE_SOLARPANNEL = SOLARPANNEL__STATIC;
int32_t TILE_NAKED1 = NAKED1__STATIC;
int32_t TILE_ANTENNA = ANTENNA__STATIC;
int32_t TILE_MASKWALL12 = MASKWALL12__STATIC;
int32_t TILE_TOILETBROKE = TOILETBROKE__STATIC;
int32_t TILE_PIPE2 = PIPE2__STATIC;
int32_t TILE_PIPE1B = PIPE1B__STATIC;
int32_t TILE_PIPE3 = PIPE3__STATIC;
int32_t TILE_PIPE1 = PIPE1__STATIC;
int32_t TILE_CAMERA1 = CAMERA1__STATIC;
int32_t TILE_BRICK = BRICK__STATIC;
int32_t TILE_SPLINTERWOOD = SPLINTERWOOD__STATIC;
int32_t TILE_PIPE2B = PIPE2B__STATIC;
int32_t TILE_BOLT1 = BOLT1__STATIC;
int32_t TILE_W_NUMBERS = W_NUMBERS__STATIC;
int32_t TILE_WATERDRIP = WATERDRIP__STATIC;
int32_t TILE_WATERBUBBLE = WATERBUBBLE__STATIC;
int32_t TILE_WATERBUBBLEMAKER = WATERBUBBLEMAKER__STATIC;
int32_t TILE_W_FORCEFIELD = W_FORCEFIELD__STATIC;
int32_t TILE_VACUUM = VACUUM__STATIC;
int32_t TILE_FOOTPRINTS2 = FOOTPRINTS2__STATIC;
int32_t TILE_FOOTPRINTS3 = FOOTPRINTS3__STATIC;
int32_t TILE_FOOTPRINTS4 = FOOTPRINTS4__STATIC;
int32_t TILE_EGG = EGG__STATIC;
int32_t TILE_SCALE = SCALE__STATIC;
int32_t TILE_CHAIR3 = CHAIR3__STATIC;
int32_t TILE_CAMERALIGHT = CAMERALIGHT__STATIC;
int32_t TILE_MOVIECAMERA = MOVIECAMERA__STATIC;
int32_t TILE_IVUNIT = IVUNIT__STATIC;
int32_t TILE_POT1 = POT1__STATIC;
int32_t TILE_POT2 = POT2__STATIC;
int32_t TILE_POT3 = POT3__STATIC;
int32_t TILE_PIPE3B = PIPE3B__STATIC;
int32_t TILE_WALLLIGHT3 = WALLLIGHT3__STATIC;
int32_t TILE_WALLLIGHTBUST3 = WALLLIGHTBUST3__STATIC;
int32_t TILE_WALLLIGHT1 = WALLLIGHT1__STATIC;
int32_t TILE_WALLLIGHTBUST1 = WALLLIGHTBUST1__STATIC;
int32_t TILE_WALLLIGHT2 = WALLLIGHT2__STATIC;
int32_t TILE_WALLLIGHTBUST2 = WALLLIGHTBUST2__STATIC;
int32_t TILE_LIGHTSWITCH2 = LIGHTSWITCH2__STATIC;
int32_t TILE_WAITTOBESEATED = WAITTOBESEATED__STATIC;
int32_t TILE_DOORTILE14 = DOORTILE14__STATIC;
int32_t TILE_STATUE = STATUE__STATIC;
int32_t TILE_MIKE = MIKE__STATIC;
int32_t TILE_VASE = VASE__STATIC;
int32_t TILE_SUSHIPLATE1 = SUSHIPLATE1__STATIC;
int32_t TILE_SUSHIPLATE2 = SUSHIPLATE2__STATIC;
int32_t TILE_SUSHIPLATE3 = SUSHIPLATE3__STATIC;
int32_t TILE_SUSHIPLATE4 = SUSHIPLATE4__STATIC;
int32_t TILE_DOORTILE16 = DOORTILE16__STATIC;
int32_t TILE_SUSHIPLATE5 = SUSHIPLATE5__STATIC;
int32_t TILE_OJ = OJ__STATIC;
int32_t TILE_MASKWALL13 = MASKWALL13__STATIC;
int32_t TILE_HURTRAIL = HURTRAIL__STATIC;
int32_t TILE_POWERSWITCH1 = POWERSWITCH1__STATIC;
int32_t TILE_LOCKSWITCH1 = LOCKSWITCH1__STATIC;
int32_t TILE_POWERSWITCH2 = POWERSWITCH2__STATIC;
int32_t TILE_ATM = ATM__STATIC;
int32_t TILE_STATUEFLASH = STATUEFLASH__STATIC;
int32_t TILE_ATMBROKE = ATMBROKE__STATIC;
int32_t TILE_BIGHOLE2 = BIGHOLE2__STATIC;
int32_t TILE_STRIPEBALL = STRIPEBALL__STATIC;
int32_t TILE_QUEBALL = QUEBALL__STATIC;
int32_t TILE_POCKET = POCKET__STATIC;
int32_t TILE_WOODENHORSE = WOODENHORSE__STATIC;
int32_t TILE_TREE1 = TREE1__STATIC;
int32_t TILE_TREE2 = TREE2__STATIC;
int32_t TILE_CACTUS = CACTUS__STATIC;
int32_t TILE_MASKWALL2 = MASKWALL2__STATIC;
int32_t TILE_MASKWALL3 = MASKWALL3__STATIC;
int32_t TILE_MASKWALL4 = MASKWALL4__STATIC;
int32_t TILE_FIREEXT = FIREEXT__STATIC;
int32_t TILE_TOILETWATER = TOILETWATER__STATIC;
int32_t TILE_NEON1 = NEON1__STATIC;
int32_t TILE_NEON2 = NEON2__STATIC;
int32_t TILE_CACTUSBROKE = CACTUSBROKE__STATIC;
int32_t TILE_BOUNCEMINE = BOUNCEMINE__STATIC;
int32_t TILE_BROKEFIREHYDRENT = BROKEFIREHYDRENT__STATIC;
int32_t TILE_BOX = BOX__STATIC;
int32_t TILE_BULLETHOLE = BULLETHOLE__STATIC;
int32_t TILE_BOTTLE1 = BOTTLE1__STATIC;
int32_t TILE_BOTTLE2 = BOTTLE2__STATIC;
int32_t TILE_BOTTLE3 = BOTTLE3__STATIC;
int32_t TILE_BOTTLE4 = BOTTLE4__STATIC;
int32_t TILE_FEMPIC5 = FEMPIC5__STATIC;
int32_t TILE_FEMPIC6 = FEMPIC6__STATIC;
int32_t TILE_FEMPIC7 = FEMPIC7__STATIC;
int32_t TILE_HYDROPLANT = HYDROPLANT__STATIC;
int32_t TILE_OCEANSPRITE1 = OCEANSPRITE1__STATIC;
int32_t TILE_OCEANSPRITE2 = OCEANSPRITE2__STATIC;
int32_t TILE_OCEANSPRITE3 = OCEANSPRITE3__STATIC;
int32_t TILE_OCEANSPRITE4 = OCEANSPRITE4__STATIC;
int32_t TILE_OCEANSPRITE5 = OCEANSPRITE5__STATIC;
int32_t TILE_GENERICPOLE = GENERICPOLE__STATIC;
int32_t TILE_CONE = CONE__STATIC;
int32_t TILE_HANGLIGHT = HANGLIGHT__STATIC;
int32_t TILE_HYDRENT = HYDRENT__STATIC;
int32_t TILE_MASKWALL14 = MASKWALL14__STATIC;
int32_t TILE_TIRE = TIRE__STATIC;
int32_t TILE_PIPE5 = PIPE5__STATIC;
int32_t TILE_PIPE6 = PIPE6__STATIC;
int32_t TILE_PIPE4 = PIPE4__STATIC;
int32_t TILE_PIPE4B = PIPE4B__STATIC;
int32_t TILE_BROKEHYDROPLANT = BROKEHYDROPLANT__STATIC;
int32_t TILE_PIPE5B = PIPE5B__STATIC;
int32_t TILE_NEON3 = NEON3__STATIC;
int32_t TILE_NEON4 = NEON4__STATIC;
int32_t TILE_NEON5 = NEON5__STATIC;
int32_t TILE_BOTTLE5 = BOTTLE5__STATIC;
int32_t TILE_BOTTLE6 = BOTTLE6__STATIC;
int32_t TILE_BOTTLE8 = BOTTLE8__STATIC;
int32_t TILE_SPOTLITE = SPOTLITE__STATIC;
int32_t TILE_HANGOOZ = HANGOOZ__STATIC;
int32_t TILE_MASKWALL15 = MASKWALL15__STATIC;
int32_t TILE_BOTTLE7 = BOTTLE7__STATIC;
int32_t TILE_HORSEONSIDE = HORSEONSIDE__STATIC;
int32_t TILE_GLASSPIECES = GLASSPIECES__STATIC;
int32_t TILE_HORSELITE = HORSELITE__STATIC;
int32_t TILE_DONUTS = DONUTS__STATIC;
int32_t TILE_NEON6 = NEON6__STATIC;
int32_t TILE_MASKWALL6 = MASKWALL6__STATIC;
int32_t TILE_CLOCK = CLOCK__STATIC;
int32_t TILE_RUBBERCAN = RUBBERCAN__STATIC;
int32_t TILE_BROKENCLOCK = BROKENCLOCK__STATIC;
int32_t TILE_PLUG = PLUG__STATIC;
int32_t TILE_OOZFILTER = OOZFILTER__STATIC;
int32_t TILE_FLOORPLASMA = FLOORPLASMA__STATIC;
int32_t TILE_REACTOR = REACTOR__STATIC;
int32_t TILE_REACTORSPARK = REACTORSPARK__STATIC;
int32_t TILE_REACTORBURNT = REACTORBURNT__STATIC;
int32_t TILE_DOORTILE15 = DOORTILE15__STATIC;
int32_t TILE_HANDSWITCH = HANDSWITCH__STATIC;
int32_t TILE_CIRCLEPANNEL = CIRCLEPANNEL__STATIC;
int32_t TILE_CIRCLEPANNELBROKE = CIRCLEPANNELBROKE__STATIC;
int32_t TILE_PULLSWITCH = PULLSWITCH__STATIC;
int32_t TILE_MASKWALL8 = MASKWALL8__STATIC;
int32_t TILE_BIGHOLE = BIGHOLE__STATIC;
int32_t TILE_ALIENSWITCH = ALIENSWITCH__STATIC;
int32_t TILE_DOORTILE21 = DOORTILE21__STATIC;
int32_t TILE_HANDPRINTSWITCH = HANDPRINTSWITCH__STATIC;
int32_t TILE_BOTTLE10 = BOTTLE10__STATIC;
int32_t TILE_BOTTLE11 = BOTTLE11__STATIC;
int32_t TILE_BOTTLE12 = BOTTLE12__STATIC;
int32_t TILE_BOTTLE13 = BOTTLE13__STATIC;
int32_t TILE_BOTTLE14 = BOTTLE14__STATIC;
int32_t TILE_BOTTLE15 = BOTTLE15__STATIC;
int32_t TILE_BOTTLE16 = BOTTLE16__STATIC;
int32_t TILE_BOTTLE17 = BOTTLE17__STATIC;
int32_t TILE_BOTTLE18 = BOTTLE18__STATIC;
int32_t TILE_BOTTLE19 = BOTTLE19__STATIC;
int32_t TILE_DOORTILE17 = DOORTILE17__STATIC;
int32_t TILE_MASKWALL7 = MASKWALL7__STATIC;
int32_t TILE_JAILBARBREAK = JAILBARBREAK__STATIC;
int32_t TILE_DOORTILE11 = DOORTILE11__STATIC;
int32_t TILE_DOORTILE12 = DOORTILE12__STATIC;
int32_t TILE_VENDMACHINE = VENDMACHINE__STATIC;
int32_t TILE_VENDMACHINEBROKE = VENDMACHINEBROKE__STATIC;
int32_t TILE_COLAMACHINE = COLAMACHINE__STATIC;
int32_t TILE_COLAMACHINEBROKE = COLAMACHINEBROKE__STATIC;
int32_t TILE_CRANEPOLE = CRANEPOLE__STATIC;
int32_t TILE_CRANE = CRANE__STATIC;
int32_t TILE_BARBROKE = BARBROKE__STATIC;
int32_t TILE_BLOODPOOL = BLOODPOOL__STATIC;
int32_t TILE_NUKEBARREL = NUKEBARREL__STATIC;
int32_t TILE_NUKEBARRELDENTED = NUKEBARRELDENTED__STATIC;
int32_t TILE_NUKEBARRELLEAKED = NUKEBARRELLEAKED__STATIC;
int32_t TILE_CANWITHSOMETHING = CANWITHSOMETHING__STATIC;
int32_t TILE_MONEY = MONEY__STATIC;
int32_t TILE_BANNER = BANNER__STATIC;
int32_t TILE_EXPLODINGBARREL = EXPLODINGBARREL__STATIC;
int32_t TILE_EXPLODINGBARREL2 = EXPLODINGBARREL2__STATIC;
int32_t TILE_FIREBARREL = FIREBARREL__STATIC;
int32_t TILE_SEENINE = SEENINE__STATIC;
int32_t TILE_SEENINEDEAD = SEENINEDEAD__STATIC;
int32_t TILE_STEAM = STEAM__STATIC;
int32_t TILE_CEILINGSTEAM = CEILINGSTEAM__STATIC;
int32_t TILE_PIPE6B = PIPE6B__STATIC;
int32_t TILE_TRANSPORTERBEAM = TRANSPORTERBEAM__STATIC;
int32_t TILE_RAT = RAT__STATIC;
int32_t TILE_TRASH = TRASH__STATIC;
int32_t TILE_FEMPIC1 = FEMPIC1__STATIC;
int32_t TILE_FEMPIC2 = FEMPIC2__STATIC;
int32_t TILE_BLANKSCREEN = BLANKSCREEN__STATIC;
int32_t TILE_PODFEM1 = PODFEM1__STATIC;
int32_t TILE_FEMPIC3 = FEMPIC3__STATIC;
int32_t TILE_FEMPIC4 = FEMPIC4__STATIC;
int32_t TILE_FEM1 = FEM1__STATIC;
int32_t TILE_FEM2 = FEM2__STATIC;
int32_t TILE_FEM3 = FEM3__STATIC;
int32_t TILE_FEM5 = FEM5__STATIC;
int32_t TILE_BLOODYPOLE = BLOODYPOLE__STATIC;
int32_t TILE_FEM4 = FEM4__STATIC;
int32_t TILE_FEM6 = FEM6__STATIC;
int32_t TILE_FEM6PAD = FEM6PAD__STATIC;
int32_t TILE_FEM8 = FEM8__STATIC;
int32_t TILE_HELECOPT = HELECOPT__STATIC;
int32_t TILE_FETUSJIB = FETUSJIB__STATIC;
int32_t TILE_HOLODUKE = HOLODUKE__STATIC;
int32_t TILE_SPACEMARINE = SPACEMARINE__STATIC;
int32_t TILE_INDY = INDY__STATIC;
int32_t TILE_FETUS = FETUS__STATIC;
int32_t TILE_FETUSBROKE = FETUSBROKE__STATIC;
int32_t TILE_MONK = MONK__STATIC;
int32_t TILE_LUKE = LUKE__STATIC;
int32_t TILE_COOLEXPLOSION1 = COOLEXPLOSION1__STATIC;
int32_t TILE_WATERSPLASH2 = WATERSPLASH2__STATIC;
int32_t TILE_FIREVASE = FIREVASE__STATIC;
int32_t TILE_SCRATCH = SCRATCH__STATIC;
int32_t TILE_FEM7 = FEM7__STATIC;
int32_t TILE_APLAYERTOP = APLAYERTOP__STATIC;
int32_t TILE_APLAYER = APLAYER__STATIC;
int32_t TILE_PLAYERONWATER = PLAYERONWATER__STATIC;
int32_t TILE_DUKELYINGDEAD = DUKELYINGDEAD__STATIC;
int32_t TILE_DUKETORSO = DUKETORSO__STATIC;
int32_t TILE_DUKEGUN = DUKEGUN__STATIC;
int32_t TILE_DUKELEG = DUKELEG__STATIC;
int32_t TILE_SHARK = SHARK__STATIC;
int32_t TILE_BLOOD = BLOOD__STATIC;
int32_t TILE_FIRELASER = FIRELASER__STATIC;
int32_t TILE_TRANSPORTERSTAR = TRANSPORTERSTAR__STATIC;
int32_t TILE_SPIT = SPIT__STATIC;
int32_t TILE_LOOGIE = LOOGIE__STATIC;
int32_t TILE_FIST = FIST__STATIC;
int32_t TILE_FREEZEBLAST = FREEZEBLAST__STATIC;
int32_t TILE_DEVISTATORBLAST = DEVISTATORBLAST__STATIC;
int32_t TILE_SHRINKSPARK = SHRINKSPARK__STATIC;
int32_t TILE_TONGUE = TONGUE__STATIC;
int32_t TILE_MORTER = MORTER__STATIC;
int32_t TILE_SHRINKEREXPLOSION = SHRINKEREXPLOSION__STATIC;
int32_t TILE_RADIUSEXPLOSION = RADIUSEXPLOSION__STATIC;
int32_t TILE_FORCERIPPLE = FORCERIPPLE__STATIC;
int32_t TILE_LIZTROOP = LIZTROOP__STATIC;
int32_t TILE_LIZTROOPRUNNING = LIZTROOPRUNNING__STATIC;
int32_t TILE_LIZTROOPSTAYPUT = LIZTROOPSTAYPUT__STATIC;
int32_t TILE_LIZTOP = LIZTOP__STATIC;
int32_t TILE_LIZTROOPSHOOT = LIZTROOPSHOOT__STATIC;
int32_t TILE_LIZTROOPJETPACK = LIZTROOPJETPACK__STATIC;
int32_t TILE_LIZTROOPDSPRITE = LIZTROOPDSPRITE__STATIC;
int32_t TILE_LIZTROOPONTOILET = LIZTROOPONTOILET__STATIC;
int32_t TILE_LIZTROOPJUSTSIT = LIZTROOPJUSTSIT__STATIC;
int32_t TILE_LIZTROOPDUCKING = LIZTROOPDUCKING__STATIC;
int32_t TILE_HEADJIB1 = HEADJIB1__STATIC;
int32_t TILE_ARMJIB1 = ARMJIB1__STATIC;
int32_t TILE_LEGJIB1 = LEGJIB1__STATIC;
int32_t TILE_CANNONBALL = CANNONBALL__STATIC;
int32_t TILE_OCTABRAIN = OCTABRAIN__STATIC;
int32_t TILE_OCTABRAINSTAYPUT = OCTABRAINSTAYPUT__STATIC;
int32_t TILE_OCTATOP = OCTATOP__STATIC;
int32_t TILE_OCTADEADSPRITE = OCTADEADSPRITE__STATIC;
int32_t TILE_INNERJAW = INNERJAW__STATIC;
int32_t TILE_DRONE = DRONE__STATIC;
int32_t TILE_EXPLOSION2 = EXPLOSION2__STATIC;
int32_t TILE_COMMANDER = COMMANDER__STATIC;
int32_t TILE_COMMANDERSTAYPUT = COMMANDERSTAYPUT__STATIC;
int32_t TILE_RECON = RECON__STATIC;
int32_t TILE_TANK = TANK__STATIC;
int32_t TILE_PIGCOP = PIGCOP__STATIC;
int32_t TILE_PIGCOPSTAYPUT = PIGCOPSTAYPUT__STATIC;
int32_t TILE_PIGCOPDIVE = PIGCOPDIVE__STATIC;
int32_t TILE_PIGCOPDEADSPRITE = PIGCOPDEADSPRITE__STATIC;
int32_t TILE_PIGTOP = PIGTOP__STATIC;
int32_t TILE_LIZMAN = LIZMAN__STATIC;
int32_t TILE_LIZMANSTAYPUT = LIZMANSTAYPUT__STATIC;
int32_t TILE_LIZMANSPITTING = LIZMANSPITTING__STATIC;
int32_t TILE_LIZMANFEEDING = LIZMANFEEDING__STATIC;
int32_t TILE_LIZMANJUMP = LIZMANJUMP__STATIC;
int32_t TILE_LIZMANDEADSPRITE = LIZMANDEADSPRITE__STATIC;
int32_t TILE_FECES = FECES__STATIC;
int32_t TILE_LIZMANHEAD1 = LIZMANHEAD1__STATIC;
int32_t TILE_LIZMANARM1 = LIZMANARM1__STATIC;
int32_t TILE_LIZMANLEG1 = LIZMANLEG1__STATIC;
int32_t TILE_EXPLOSION2BOT = EXPLOSION2BOT__STATIC;
int32_t TILE_USERWEAPON = USERWEAPON__STATIC;
int32_t TILE_HEADERBAR = HEADERBAR__STATIC;
int32_t TILE_JIBS1 = JIBS1__STATIC;
int32_t TILE_JIBS2 = JIBS2__STATIC;
int32_t TILE_JIBS3 = JIBS3__STATIC;
int32_t TILE_JIBS4 = JIBS4__STATIC;
int32_t TILE_JIBS5 = JIBS5__STATIC;
int32_t TILE_BURNING = BURNING__STATIC;
int32_t TILE_FIRE = FIRE__STATIC;
int32_t TILE_JIBS6 = JIBS6__STATIC;
int32_t TILE_BLOODSPLAT1 = BLOODSPLAT1__STATIC;
int32_t TILE_BLOODSPLAT3 = BLOODSPLAT3__STATIC;
int32_t TILE_BLOODSPLAT2 = BLOODSPLAT2__STATIC;
int32_t TILE_BLOODSPLAT4 = BLOODSPLAT4__STATIC;
int32_t TILE_OOZ = OOZ__STATIC;
int32_t TILE_OOZ2 = OOZ2__STATIC;
int32_t TILE_WALLBLOOD1 = WALLBLOOD1__STATIC;
int32_t TILE_WALLBLOOD2 = WALLBLOOD2__STATIC;
int32_t TILE_WALLBLOOD3 = WALLBLOOD3__STATIC;
int32_t TILE_WALLBLOOD4 = WALLBLOOD4__STATIC;
int32_t TILE_WALLBLOOD5 = WALLBLOOD5__STATIC;
int32_t TILE_WALLBLOOD6 = WALLBLOOD6__STATIC;
int32_t TILE_WALLBLOOD7 = WALLBLOOD7__STATIC;
int32_t TILE_WALLBLOOD8 = WALLBLOOD8__STATIC;
int32_t TILE_BURNING2 = BURNING2__STATIC;
int32_t TILE_FIRE2 = FIRE2__STATIC;
int32_t TILE_CRACKKNUCKLES = CRACKKNUCKLES__STATIC;
int32_t TILE_SMALLSMOKE = SMALLSMOKE__STATIC;
int32_t TILE_SMALLSMOKEMAKER = SMALLSMOKEMAKER__STATIC;
int32_t TILE_FLOORFLAME = FLOORFLAME__STATIC;
int32_t TILE_ROTATEGUN = ROTATEGUN__STATIC;
int32_t TILE_GREENSLIME = GREENSLIME__STATIC;
int32_t TILE_WATERDRIPSPLASH = WATERDRIPSPLASH__STATIC;
int32_t TILE_SCRAP6 = SCRAP6__STATIC;
int32_t TILE_SCRAP1 = SCRAP1__STATIC;
int32_t TILE_SCRAP2 = SCRAP2__STATIC;
int32_t TILE_SCRAP3 = SCRAP3__STATIC;
int32_t TILE_SCRAP4 = SCRAP4__STATIC;
int32_t TILE_SCRAP5 = SCRAP5__STATIC;
int32_t TILE_ORGANTIC = ORGANTIC__STATIC;
int32_t TILE_BETAVERSION = BETAVERSION__STATIC;
int32_t TILE_PLAYERISHERE = PLAYERISHERE__STATIC;
int32_t TILE_PLAYERWASHERE = PLAYERWASHERE__STATIC;
int32_t TILE_SELECTDIR = SELECTDIR__STATIC;
int32_t TILE_F1HELP = F1HELP__STATIC;
int32_t TILE_NOTCHON = NOTCHON__STATIC;
int32_t TILE_NOTCHOFF = NOTCHOFF__STATIC;
int32_t TILE_GROWSPARK = GROWSPARK__STATIC;
int32_t TILE_DUKEICON = DUKEICON__STATIC;
int32_t TILE_BADGUYICON = BADGUYICON__STATIC;
int32_t TILE_FOODICON = FOODICON__STATIC;
int32_t TILE_GETICON = GETICON__STATIC;
int32_t TILE_MENUSCREEN = MENUSCREEN__STATIC;
int32_t TILE_MENUBAR = MENUBAR__STATIC;
int32_t TILE_KILLSICON = KILLSICON__STATIC;
int32_t TILE_FIRSTAID_ICON = FIRSTAID_ICON__STATIC;
int32_t TILE_HEAT_ICON = HEAT_ICON__STATIC;
int32_t TILE_BOTTOMSTATUSBAR = BOTTOMSTATUSBAR__STATIC;
int32_t TILE_BOOT_ICON = BOOT_ICON__STATIC;
int32_t TILE_FRAGBAR = FRAGBAR__STATIC;
int32_t TILE_JETPACK_ICON = JETPACK_ICON__STATIC;
int32_t TILE_AIRTANK_ICON = AIRTANK_ICON__STATIC;
int32_t TILE_STEROIDS_ICON = STEROIDS_ICON__STATIC;
int32_t TILE_HOLODUKE_ICON = HOLODUKE_ICON__STATIC;
int32_t TILE_ACCESS_ICON = ACCESS_ICON__STATIC;
int32_t TILE_DIGITALNUM = DIGITALNUM__STATIC;
int32_t TILE_DUKECAR = DUKECAR__STATIC;
int32_t TILE_CAMCORNER = CAMCORNER__STATIC;
int32_t TILE_CAMLIGHT = CAMLIGHT__STATIC;
int32_t TILE_LOGO = LOGO__STATIC;
int32_t TILE_TITLE = TITLE__STATIC;
int32_t TILE_NUKEWARNINGICON = NUKEWARNINGICON__STATIC;
int32_t TILE_MOUSECURSOR = MOUSECURSOR__STATIC;
int32_t TILE_SLIDEBAR = SLIDEBAR__STATIC;
int32_t TILE_DREALMS = DREALMS__STATIC;
int32_t TILE_BETASCREEN = BETASCREEN__STATIC;
int32_t TILE_WINDOWBORDER1 = WINDOWBORDER1__STATIC;
int32_t TILE_TEXTBOX = TEXTBOX__STATIC;
int32_t TILE_WINDOWBORDER2 = WINDOWBORDER2__STATIC;
int32_t TILE_DUKENUKEM = DUKENUKEM__STATIC;
int32_t TILE_THREEDEE = THREEDEE__STATIC;
int32_t TILE_INGAMEDUKETHREEDEE = INGAMEDUKETHREEDEE__STATIC;
int32_t TILE_TENSCREEN = TENSCREEN__STATIC;
int32_t TILE_PLUTOPAKSPRITE = PLUTOPAKSPRITE__STATIC;
int32_t TILE_DEVISTATOR = DEVISTATOR__STATIC;
int32_t TILE_KNEE = KNEE__STATIC;
int32_t TILE_CROSSHAIR = CROSSHAIR__STATIC;
int32_t TILE_FIRSTGUN = FIRSTGUN__STATIC;
int32_t TILE_FIRSTGUNRELOAD = FIRSTGUNRELOAD__STATIC;
int32_t TILE_FALLINGCLIP = FALLINGCLIP__STATIC;
int32_t TILE_CLIPINHAND = CLIPINHAND__STATIC;
int32_t TILE_HAND = HAND__STATIC;
int32_t TILE_SHELL = SHELL__STATIC;
int32_t TILE_SHOTGUNSHELL = SHOTGUNSHELL__STATIC;
int32_t TILE_CHAINGUN = CHAINGUN__STATIC;
int32_t TILE_RPGGUN = RPGGUN__STATIC;
int32_t TILE_RPGMUZZLEFLASH = RPGMUZZLEFLASH__STATIC;
int32_t TILE_FREEZE = FREEZE__STATIC;
int32_t TILE_CATLITE = CATLITE__STATIC;
int32_t TILE_SHRINKER = SHRINKER__STATIC;
int32_t TILE_HANDHOLDINGLASER = HANDHOLDINGLASER__STATIC;
int32_t TILE_TRIPBOMB = TRIPBOMB__STATIC;
int32_t TILE_LASERLINE = LASERLINE__STATIC;
int32_t TILE_HANDHOLDINGACCESS = HANDHOLDINGACCESS__STATIC;
int32_t TILE_HANDREMOTE = HANDREMOTE__STATIC;
int32_t TILE_HANDTHROW = HANDTHROW__STATIC;
int32_t TILE_TIP = TIP__STATIC;
int32_t TILE_GLAIR = GLAIR__STATIC;
int32_t TILE_SCUBAMASK = SCUBAMASK__STATIC;
int32_t TILE_SPACEMASK = SPACEMASK__STATIC;
int32_t TILE_FORCESPHERE = FORCESPHERE__STATIC;
int32_t TILE_SHOTSPARK1 = SHOTSPARK1__STATIC;
int32_t TILE_RPG = RPG__STATIC;
int32_t TILE_LASERSITE = LASERSITE__STATIC;
int32_t TILE_SHOTGUN = SHOTGUN__STATIC;
int32_t TILE_BOSS1 = BOSS1__STATIC;
int32_t TILE_BOSS1STAYPUT = BOSS1STAYPUT__STATIC;
int32_t TILE_BOSS1SHOOT = BOSS1SHOOT__STATIC;
int32_t TILE_BOSS1LOB = BOSS1LOB__STATIC;
int32_t TILE_BOSSTOP = BOSSTOP__STATIC;
int32_t TILE_BOSS2 = BOSS2__STATIC;
int32_t TILE_BOSS3 = BOSS3__STATIC;
int32_t TILE_SPINNINGNUKEICON = SPINNINGNUKEICON__STATIC;
int32_t TILE_BIGFNTCURSOR = BIGFNTCURSOR__STATIC;
int32_t TILE_SMALLFNTCURSOR = SMALLFNTCURSOR__STATIC;
int32_t TILE_STARTALPHANUM = STARTALPHANUM__STATIC;
int32_t TILE_ENDALPHANUM = ENDALPHANUM__STATIC;
int32_t TILE_BIGALPHANUM = BIGALPHANUM__STATIC;
int32_t TILE_BIGPERIOD = BIGPERIOD__STATIC;
int32_t TILE_BIGCOMMA = BIGCOMMA__STATIC;
// "BIGX" clashes on the Wii?
int32_t TILE_BIGX_ = BIGX__STATIC;
int32_t TILE_BIGQ = BIGQ__STATIC;
int32_t TILE_BIGSEMI = BIGSEMI__STATIC;
int32_t TILE_BIGCOLIN = BIGCOLIN__STATIC;
int32_t TILE_THREEBYFIVE = THREEBYFIVE__STATIC;
int32_t TILE_BIGAPPOS = BIGAPPOS__STATIC;
int32_t TILE_BLANK = BLANK__STATIC;
int32_t TILE_MINIFONT = MINIFONT__STATIC;
int32_t TILE_BUTTON1 = BUTTON1__STATIC;
int32_t TILE_GLASS3 = GLASS3__STATIC;
int32_t TILE_RESPAWNMARKERRED = RESPAWNMARKERRED__STATIC;
int32_t TILE_RESPAWNMARKERYELLOW = RESPAWNMARKERYELLOW__STATIC;
int32_t TILE_RESPAWNMARKERGREEN = RESPAWNMARKERGREEN__STATIC;
int32_t TILE_BONUSSCREEN = BONUSSCREEN__STATIC;
int32_t TILE_VIEWBORDER = VIEWBORDER__STATIC;
int32_t TILE_VICTORY1 = VICTORY1__STATIC;
int32_t TILE_ORDERING = ORDERING__STATIC;
int32_t TILE_TEXTSTORY = TEXTSTORY__STATIC;
int32_t TILE_LOADSCREEN = LOADSCREEN__STATIC;
int32_t TILE_BORNTOBEWILDSCREEN = BORNTOBEWILDSCREEN__STATIC;
int32_t TILE_BLIMP = BLIMP__STATIC;
int32_t TILE_FEM9 = FEM9__STATIC;
int32_t TILE_FOOTPRINT = FOOTPRINT__STATIC;
int32_t TILE_POOP = POOP__STATIC;
int32_t TILE_FRAMEEFFECT1 = FRAMEEFFECT1__STATIC;
int32_t TILE_PANNEL3 = PANNEL3__STATIC;
int32_t TILE_SCREENBREAK14 = SCREENBREAK14__STATIC;
int32_t TILE_SCREENBREAK15 = SCREENBREAK15__STATIC;
int32_t TILE_SCREENBREAK19 = SCREENBREAK19__STATIC;
int32_t TILE_SCREENBREAK16 = SCREENBREAK16__STATIC;
int32_t TILE_SCREENBREAK17 = SCREENBREAK17__STATIC;
int32_t TILE_SCREENBREAK18 = SCREENBREAK18__STATIC;
int32_t TILE_W_TECHWALL11 = W_TECHWALL11__STATIC;
int32_t TILE_W_TECHWALL12 = W_TECHWALL12__STATIC;
int32_t TILE_W_TECHWALL13 = W_TECHWALL13__STATIC;
int32_t TILE_W_TECHWALL14 = W_TECHWALL14__STATIC;
int32_t TILE_W_TECHWALL5 = W_TECHWALL5__STATIC;
int32_t TILE_W_TECHWALL6 = W_TECHWALL6__STATIC;
int32_t TILE_W_TECHWALL7 = W_TECHWALL7__STATIC;
int32_t TILE_W_TECHWALL8 = W_TECHWALL8__STATIC;
int32_t TILE_W_TECHWALL9 = W_TECHWALL9__STATIC;
int32_t TILE_BPANNEL3 = BPANNEL3__STATIC;
int32_t TILE_W_HITTECHWALL16 = W_HITTECHWALL16__STATIC;
int32_t TILE_W_HITTECHWALL10 = W_HITTECHWALL10__STATIC;
int32_t TILE_W_HITTECHWALL15 = W_HITTECHWALL15__STATIC;
int32_t TILE_W_MILKSHELF = W_MILKSHELF__STATIC;
int32_t TILE_W_MILKSHELFBROKE = W_MILKSHELFBROKE__STATIC;
int32_t TILE_PURPLELAVA = PURPLELAVA__STATIC;
int32_t TILE_LAVABUBBLE = LAVABUBBLE__STATIC;
int32_t TILE_DUKECUTOUT = DUKECUTOUT__STATIC;
int32_t TILE_TARGET = TARGET__STATIC;
int32_t TILE_GUNPOWDERBARREL = GUNPOWDERBARREL__STATIC;
int32_t TILE_DUCK = DUCK__STATIC;
int32_t TILE_HATRACK = HATRACK__STATIC;
int32_t TILE_DESKLAMP = DESKLAMP__STATIC;
int32_t TILE_COFFEEMACHINE = COFFEEMACHINE__STATIC;
int32_t TILE_CUPS = CUPS__STATIC;
int32_t TILE_GAVALS = GAVALS__STATIC;
int32_t TILE_GAVALS2 = GAVALS2__STATIC;
int32_t TILE_POLICELIGHTPOLE = POLICELIGHTPOLE__STATIC;
int32_t TILE_FLOORBASKET = FLOORBASKET__STATIC;
int32_t TILE_PUKE = PUKE__STATIC;
int32_t TILE_DOORTILE23 = DOORTILE23__STATIC;
int32_t TILE_TOPSECRET = TOPSECRET__STATIC;
int32_t TILE_SPEAKER = SPEAKER__STATIC;
int32_t TILE_TEDDYBEAR = TEDDYBEAR__STATIC;
int32_t TILE_ROBOTDOG = ROBOTDOG__STATIC;
int32_t TILE_ROBOTPIRATE = ROBOTPIRATE__STATIC;
int32_t TILE_ROBOTMOUSE = ROBOTMOUSE__STATIC;
int32_t TILE_MAIL = MAIL__STATIC;
int32_t TILE_MAILBAG = MAILBAG__STATIC;
int32_t TILE_HOTMEAT = HOTMEAT__STATIC;
int32_t TILE_COFFEEMUG = COFFEEMUG__STATIC;
int32_t TILE_DONUTS2 = DONUTS2__STATIC;
int32_t TILE_TRIPODCAMERA = TRIPODCAMERA__STATIC;
int32_t TILE_METER = METER__STATIC;
int32_t TILE_DESKPHONE = DESKPHONE__STATIC;
int32_t TILE_GUMBALLMACHINE = GUMBALLMACHINE__STATIC;
int32_t TILE_GUMBALLMACHINEBROKE = GUMBALLMACHINEBROKE__STATIC;
int32_t TILE_PAPER = PAPER__STATIC;
int32_t TILE_MACE = MACE__STATIC;
int32_t TILE_GENERICPOLE2 = GENERICPOLE2__STATIC;
int32_t TILE_XXXSTACY = XXXSTACY__STATIC;
int32_t TILE_WETFLOOR = WETFLOOR__STATIC;
int32_t TILE_BROOM = BROOM__STATIC;
int32_t TILE_MOP = MOP__STATIC;
int32_t TILE_LETTER = LETTER__STATIC;
int32_t TILE_PIRATE1A = PIRATE1A__STATIC;
int32_t TILE_PIRATE4A = PIRATE4A__STATIC;
int32_t TILE_PIRATE2A = PIRATE2A__STATIC;
int32_t TILE_PIRATE5A = PIRATE5A__STATIC;
int32_t TILE_PIRATE3A = PIRATE3A__STATIC;
int32_t TILE_PIRATE6A = PIRATE6A__STATIC;
int32_t TILE_PIRATEHALF = PIRATEHALF__STATIC;
int32_t TILE_CHESTOFGOLD = CHESTOFGOLD__STATIC;
int32_t TILE_SIDEBOLT1 = SIDEBOLT1__STATIC;
int32_t TILE_HEADLAMP = HEADLAMP__STATIC;
int32_t TILE_TAMPON = TAMPON__STATIC;
int32_t TILE_SKINNEDCHICKEN = SKINNEDCHICKEN__STATIC;
int32_t TILE_FEATHEREDCHICKEN = FEATHEREDCHICKEN__STATIC;
int32_t TILE_ROBOTDOG2 = ROBOTDOG2__STATIC;
int32_t TILE_JOLLYMEAL = JOLLYMEAL__STATIC;
int32_t TILE_DUKEBURGER = DUKEBURGER__STATIC;
int32_t TILE_SHOPPINGCART = SHOPPINGCART__STATIC;
int32_t TILE_CANWITHSOMETHING2 = CANWITHSOMETHING2__STATIC;
int32_t TILE_CANWITHSOMETHING3 = CANWITHSOMETHING3__STATIC;
int32_t TILE_CANWITHSOMETHING4 = CANWITHSOMETHING4__STATIC;
int32_t TILE_SNAKEP = SNAKEP__STATIC;
int32_t TILE_DOLPHIN1 = DOLPHIN1__STATIC;
int32_t TILE_DOLPHIN2 = DOLPHIN2__STATIC;
int32_t TILE_NEWBEAST = NEWBEAST__STATIC;
int32_t TILE_NEWBEASTSTAYPUT = NEWBEASTSTAYPUT__STATIC;
int32_t TILE_NEWBEASTJUMP = NEWBEASTJUMP__STATIC;
int32_t TILE_NEWBEASTHANG = NEWBEASTHANG__STATIC;
int32_t TILE_NEWBEASTHANGDEAD = NEWBEASTHANGDEAD__STATIC;
int32_t TILE_BOSS4 = BOSS4__STATIC;
int32_t TILE_BOSS4STAYPUT = BOSS4STAYPUT__STATIC;
int32_t TILE_FEM10 = FEM10__STATIC;
int32_t TILE_TOUGHGAL = TOUGHGAL__STATIC;
int32_t TILE_MAN = MAN__STATIC;
int32_t TILE_MAN2 = MAN2__STATIC;
int32_t TILE_WOMAN = WOMAN__STATIC;
int32_t TILE_PLEASEWAIT = PLEASEWAIT__STATIC;
int32_t TILE_NATURALLIGHTNING = NATURALLIGHTNING__STATIC;
int32_t TILE_WEATHERWARN = WEATHERWARN__STATIC;
int32_t TILE_DUKETAG = DUKETAG__STATIC;
int32_t TILE_SIGN1 = SIGN1__STATIC;
int32_t TILE_SIGN2 = SIGN2__STATIC;
int32_t TILE_JURYGUY = JURYGUY__STATIC;

int32_t TILE_RPG2SPRITE = 0;
int32_t TILE_DESTRUCTO = 0;
int32_t TILE_GUTMETER = 0;
int32_t TILE_SOUNDFX = 0;
int32_t TILE_MOTOAMMO = 0;
int32_t TILE_UFOBEAM = 0;
int32_t TILE_CDPLAYER = 0;
int32_t TILE_GUTMETER_LIGHT1 = 0;
int32_t TILE_GUTMETER_LIGHT2 = 0;
int32_t TILE_GUTMETER_LIGHT3 = 0;
int32_t TILE_GUTMETER_LIGHT4 = 0;
int32_t TILE_AMMO_ICON = 0;
int32_t TILE_RRTILE1076 = 0;
int32_t TILE_MUD = 0;
int32_t TILE_EXPLOSION3 = 0;
int32_t TILE_RRTILE1636 = 0;
int32_t TILE_WEAPONBAR = 0;
int32_t TILE_RPG2 = 0;
int32_t TILE_POPCORN = 0;
int32_t TILE_LANEPICS = 0;
int32_t TILE_SHOTGUNSHELLS = 0;
int32_t TILE_CIRCLESTUCK = 0;
int32_t TILE_LUMBERBLADE = 0;
int32_t TILE_BOWLINGBALLH = 0;
int32_t TILE_BOWLINGBALL = 0;
int32_t TILE_BOWLINGBALLSPRITE = 0;
int32_t TILE_POWDERH = 0;
int32_t TILE_OWHIP = 0;
int32_t TILE_UWHIP = 0;
int32_t TILE_RPGGUN2 = 0;
int32_t TILE_SLINGBLADE = 0;
int32_t TILE_MOTOGUN = 0;
int32_t TILE_MOTOHIT = 0;
int32_t TILE_BOATHIT = 0;
int32_t TILE_EMPTYBIKE = 0;
int32_t TILE_EMPTYBOAT = 0;
int32_t TILE_MULTISWITCH2 = 0;
int32_t TILE_BOATAMMO = 0;
int32_t TILE_BOULDER = 0;
int32_t TILE_BOULDER1 = 0;
int32_t TILE_TORNADO = 0;
int32_t TILE_CHEERBOMB = 0;
int32_t TILE_CHEERBLADE = 0;
int32_t TILE_DOGATTACK = 0;
int32_t TILE_BILLYWALK = 0;
int32_t TILE_BILLYDIE = 0;
int32_t TILE_BILLYCOCK = 0;
int32_t TILE_BILLYRAY = 0;
int32_t TILE_BILLYRAYSTAYPUT = 0;
int32_t TILE_BILLYBUT = 0;
int32_t TILE_BILLYSCRATCH = 0;
int32_t TILE_BILLYSNIFF = 0;
int32_t TILE_BILLYWOUND = 0;
int32_t TILE_BILLYGORE = 0;
int32_t TILE_BILLYJIBA = 0;
int32_t TILE_BILLYJIBB = 0;
int32_t TILE_BRAYSNIPER = 0;
int32_t TILE_DOGRUN = 0;
int32_t TILE_DOGDIE = 0;
int32_t TILE_DOGDEAD = 0;
int32_t TILE_DOGBARK = 0;
int32_t TILE_LTH = 0;
int32_t TILE_LTHSTRAFE = 0;
int32_t TILE_HULKHANG = 0;
int32_t TILE_HULKHANGDEAD = 0;
int32_t TILE_HULKJUMP = 0;
int32_t TILE_LTHLOAD = 0;
int32_t TILE_LTHDIE = 0;
int32_t TILE_BUBBASCRATCH = 0;
int32_t TILE_BUBBANOSE = 0;
int32_t TILE_BUBBAPISS = 0;
int32_t TILE_BUBBASTAND = 0;
int32_t TILE_BUBBAOUCH = 0;
int32_t TILE_BUBBADIE = 0;
int32_t TILE_BUBBADEAD = 0;
int32_t TILE_HULK = 0;
int32_t TILE_HULKSTAYPUT = 0;
int32_t TILE_HULKA = 0;
int32_t TILE_HULKB = 0;
int32_t TILE_HULKC = 0;
int32_t TILE_HULKJIBA = 0;
int32_t TILE_HULKJIBB = 0;
int32_t TILE_HULKJIBC = 0;
int32_t TILE_SBSWIPE = 0;
int32_t TILE_SBPAIN = 0;
int32_t TILE_SBDIE = 0;
int32_t TILE_HEN = 0;
int32_t TILE_HENSTAYPUT = 0;
int32_t TILE_HENSTAND = 0;
int32_t TILE_PIG = 0;
int32_t TILE_PIGSTAYPUT = 0;
int32_t TILE_PIGEAT = 0;
int32_t TILE_SBMOVE = 0;
int32_t TILE_SBSPIT = 0;
int32_t TILE_SBDIP = 0;
int32_t TILE_MINION = 0;
int32_t TILE_MINIONSTAYPUT = 0;
int32_t TILE_UFO1 = 0;
int32_t TILE_UFO2 = 0;
int32_t TILE_UFO3 = 0;
int32_t TILE_UFO4 = 0;
int32_t TILE_UFO5 = 0;
int32_t TILE_MINJIBA = 0;
int32_t TILE_MINJIBB = 0;
int32_t TILE_MINJIBC = 0;
int32_t TILE_COW = 0;
int32_t TILE_COOT = 0;
int32_t TILE_COOTSTAYPUT = 0;
int32_t TILE_COOTSHOOT = 0;
int32_t TILE_COOTDIE = 0;
int32_t TILE_COOTDUCK = 0;
int32_t TILE_COOTPAIN = 0;
int32_t TILE_COOTTRANS = 0;
int32_t TILE_COOTGETUP = 0;
int32_t TILE_COOTJIBA = 0;
int32_t TILE_COOTJIBB = 0;
int32_t TILE_COOTJIBC = 0;
int32_t TILE_VIXEN = 0;
int32_t TILE_VIXENPAIN = 0;
int32_t TILE_VIXENDIE = 0;
int32_t TILE_VIXENSHOOT = 0;
int32_t TILE_VIXENWDN = 0;
int32_t TILE_VIXENWUP = 0;
int32_t TILE_VIXENKICK = 0;
int32_t TILE_VIXENTELE = 0;
int32_t TILE_VIXENTEAT = 0;
int32_t TILE_BIKEJIBA = 0;
int32_t TILE_BIKEJIBB = 0;
int32_t TILE_BIKEJIBC = 0;
int32_t TILE_BIKERB = 0;
int32_t TILE_BIKERBV2 = 0;
int32_t TILE_BIKER = 0;
int32_t TILE_BIKERJIBA = 0;
int32_t TILE_BIKERJIBB = 0;
int32_t TILE_BIKERJIBC = 0;
int32_t TILE_BIKERJIBD = 0;
int32_t TILE_MAKEOUT = 0;
int32_t TILE_CHEERB = 0;
int32_t TILE_CHEER = 0;
int32_t TILE_CHEERSTAYPUT = 0;
int32_t TILE_CHEERJIBA = 0;
int32_t TILE_CHEERJIBB = 0;
int32_t TILE_CHEERJIBC = 0;
int32_t TILE_CHEERJIBD = 0;
int32_t TILE_FBOATJIBA = 0;
int32_t TILE_FBOATJIBB = 0;
int32_t TILE_COOTPLAY = 0;
int32_t TILE_BILLYPLAY = 0;
int32_t TILE_MINIONBOAT = 0;
int32_t TILE_HULKBOAT = 0;
int32_t TILE_CHEERBOAT = 0;
int32_t TILE_RRTILE7274 = 0;
int32_t TILE_RABBIT = 0;
int32_t TILE_RABBITJIBA = 0;
int32_t TILE_RABBITJIBB = 0;
int32_t TILE_RABBITJIBC = 0;
int32_t TILE_ROCK = 0;
int32_t TILE_ROCK2 = 0;
int32_t TILE_MAMACLOUD = 0;
int32_t TILE_MAMA = 0;
int32_t TILE_MAMAJIBA = 0;
int32_t TILE_MAMAJIBB = 0;


// This is run after all CON define's have been processed to set up the
// dynamic->static tile mapping.
void G_InitDynamicTiles(void)
{
    int32_t i;

  
    Bmemset(DynamicTileMap, 0, sizeof(DynamicTileMap));

    if (RR)
    {
        for (i = 0; g_dynTileList[i].staticval >= 0; i++) {
            *(g_dynTileList[i].dynvalptr) = -g_dynTileList[i].staticval_rr;
            if (RRRA && *(g_dynTileList[i].dynvalptr) == -UFO1__STATICRR) *(g_dynTileList[i].dynvalptr) = -UFO1__STATICRRRA;
            DynamicTileMap[*(g_dynTileList[i].dynvalptr)] = g_dynTileList[i].staticval_rr;
			NameToTileIndex.Insert(g_dynTileList[i].str, *(g_dynTileList[i].dynvalptr));
        }
        PHEIGHT = PHEIGHT_RR;
    }

    for (i=0; g_dynTileList[i].staticval >= 0; i++)
        if (g_dynTileList[i].staticval > 0)
		{
            DynamicTileMap[*(g_dynTileList[i].dynvalptr)] = g_dynTileList[i].staticval;
			NameToTileIndex.Insert(g_dynTileList[i].str, *(g_dynTileList[i].dynvalptr));
		}

    DynamicTileMap[0] = 0;
}
END_DUKE_NS
